@@ -9,9 +9,8 @@
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
 #include <gnumeric.h>
-#include <goffice/app/go-plugin.h>
+#include <goffice/goffice.h>
 #include <gnm-plugin.h>
-#include <goffice/app/io-context.h>
 #include <sheet.h>
 #include <ranges.h>
 #include <value.h>
@@ -23,8 +22,6 @@
 #include <sheet-style.h>
 #include <style.h>
 #include <mstyle.h>
-#include <goffice/utils/go-glib-extras.h>
-#include <goffice/app/error-info.h>
 
 #include <gsf/gsf-utils.h>
 #include <gsf/gsf-input.h>
@@ -281,7 +278,7 @@ pln_get_addr (GnmParsePos const *pp, guint8 const *ch)
 	guint16 r = GSF_LE_GET_GUINT16 (ch);
 	guint16 c = GSF_LE_GET_GUINT16 (ch+2);
 	GnmCellRef ref;
-	GString *str = g_string_new (NULL);
+	GnmConventionsOut out;
 
 	ref.sheet = NULL;
 	ref.col_relative = ref.row_relative = FALSE;
@@ -303,9 +300,12 @@ pln_get_addr (GnmParsePos const *pp, guint8 const *ch)
 		break;
 	}
 
-	cellref_as_string (str, gnm_expr_conventions_default, &ref, pp, TRUE);
+	out.accum = g_string_new (NULL);
+	out.pp    = pp;
+	out.convs = gnm_conventions_default;
+	cellref_as_string (&out, &ref, TRUE);
 
-	return g_string_free (str, FALSE);
+	return g_string_free (out.accum, FALSE);
 }
 
 static char *
@@ -417,7 +417,7 @@ pln_convert_expr (GnmParsePos const *pp, guint8 const *ch)
 			ch += 9 + len;
 			break;
 
-		case 31:	/* Reference to passed arguement in user defined function */
+		case 31:	/* Reference to passed argument in user defined function */
 			g_string_append (expr, "_unknown31_");
 			ch++; /* ignore arg number */
 			break;
@@ -486,8 +486,8 @@ pln_calc_font_width (guint16 cwidth, gboolean permit_default)
 static ErrorInfo *
 pln_parse_sheet (GsfInput *input, PlanPerfectImport *state)
 {
-	int max_col = SHEET_MAX_COLS;
-	int max_row = SHEET_MAX_ROWS;
+	int max_col = gnm_sheet_get_max_cols (state->sheet);
+	int max_row = gnm_sheet_get_max_rows (state->sheet);
 	int i, rcode, rlength;
 	guint8 const *data;
 	GnmValue   *v;
@@ -495,7 +495,7 @@ pln_parse_sheet (GsfInput *input, PlanPerfectImport *state)
 	GnmParsePos pp;
 	GnmRange r;
 
-	range_init (&r, 0,0,0, SHEET_MAX_ROWS);
+	range_init (&r, 0,0,0, gnm_sheet_get_max_rows (state->sheet));
 	parse_pos_init_sheet (&pp, state->sheet);
 
 	data = gsf_input_read (input, 16, NULL);
@@ -627,7 +627,7 @@ pln_parse_sheet (GsfInput *input, PlanPerfectImport *state)
 				if (expr_txt != NULL) {
 					texpr = gnm_expr_parse_str (expr_txt, &pp,
 								   GNM_EXPR_PARSE_DEFAULT,
-								   gnm_expr_conventions_default,
+								   gnm_conventions_default,
 								   NULL);
 					if (texpr == NULL) {
 						if (v != NULL)
@@ -664,7 +664,7 @@ pln_file_open (GOFileOpener const *fo, IOContext *io_context,
 
 	wb    = wb_view_get_workbook (wb_view);
 	name  = workbook_sheet_get_free_name (wb, "PlanPerfect", FALSE, TRUE);
-	sheet = sheet_new (wb, name);
+	sheet = sheet_new (wb, name, 256, 65536);
 	g_free (name);
 	workbook_sheet_attach (wb, sheet);
 	sheet_flag_recompute_spans (sheet);
