@@ -11,10 +11,8 @@
 #include "gnm-python.h"
 #include "py-gnumeric.h"
 
-#include <goffice/app/go-plugin.h>
-#include <goffice/app/error-info.h>
+#include <goffice/goffice.h>
 #include <goffice/app/module-plugin-defs.h>
-#include <goffice/utils/go-glib-extras.h>
 #include <gsf/gsf-impl-utils.h>
 
 #include <glib/gi18n-lib.h>
@@ -206,7 +204,7 @@ gnm_python_new_interpreter (GnmPython *gpy, GOPlugin *plugin)
 	GnmPyInterpreter *interpreter;
 
 	g_return_val_if_fail (IS_GNM_PYTHON (gpy), NULL);
-	g_return_val_if_fail (IS_GO_PLUGIN (plugin), NULL);
+	g_return_val_if_fail (GO_IS_PLUGIN (plugin), NULL);
 
 	interpreter = gnm_py_interpreter_new (plugin);
 	GO_SLIST_PREPEND (gpy->interpreters, interpreter);
