@@ -24,9 +24,7 @@
 #include "expr-impl.h"
 #include "func.h"
 
-#include <goffice/app/io-context.h>
-#include <goffice/app/go-plugin-service.h>
-#include <goffice/app/go-plugin-loader.h>
+#include <goffice/goffice.h>
 #include <goffice/app/module-plugin-defs.h>
 
 #include <gsf/gsf-impl-utils.h>
@@ -537,12 +535,18 @@ python_function_get_gnumeric_help (PyObject *python_fn_info_dict, PyObject *pyth
 	if (cobject_help_value == NULL) {
 		PyObject *python_fn_help = ((PyFunctionObject *) python_fn)->func_doc;
 		if (python_fn_help != NULL && PyString_Check (python_fn_help)) {
-			GnmFuncHelp *new_help = g_new(GnmFuncHelp, 2);
-			gchar *help_str = PyString_AsString (python_fn_help);
-			new_help[0].type = GNM_FUNC_HELP_OLD;
-			new_help[0].text = help_str;
-			new_help[1].type = GNM_FUNC_HELP_END;
-			new_help[1].text = NULL;
+			GnmFuncHelp *new_help = g_new (GnmFuncHelp, 2);
+			int i = 0;
+
+#if 0
+			new_help[i].type = GNM_FUNC_HELP_OLD;
+			new_help[i].text = PyString_AsString (python_fn_help);
+			i++;
+#endif
+
+			new_help[i].type = GNM_FUNC_HELP_END;
+			new_help[i].text = NULL;
+			i++;
 
 			cobject_help_value = PyCObject_FromVoidPtr (new_help, &g_free);
 			PyDict_SetItemString (python_fn_info_dict, help_attr_name, cobject_help_value);
@@ -587,7 +591,9 @@ gplp_func_desc_load (GOPluginService *service,
 		    (python_fn = PyTuple_GetItem (fn_info_obj, 2)) != NULL &&
 		    PyFunction_Check (python_fn)) {
 			res->arg_spec	= PyString_AsString (python_args);
+#if 0
 			res->arg_names  = PyString_AsString (python_arg_names);
+#endif
 			res->help	= python_function_get_gnumeric_help (
 				loader_data->python_fn_info_dict, python_fn, name);
 			res->fn_args	= &call_python_function_args;
@@ -605,7 +611,6 @@ gplp_func_desc_load (GOPluginService *service,
 
 	if (PyFunction_Check (fn_info_obj)) {
 		res->arg_spec	= "";
-		res->arg_names  = "";
 		res->help	= python_function_get_gnumeric_help (
 			loader_data->python_fn_info_dict, fn_info_obj, name);
 		res->fn_args	= NULL;
