@@ -34,6 +34,10 @@
 #include <workbook.h>
 #include <wbc-gtk.h>
 #include <application.h>
+#include <position.h>
+#include <expr.h>
+#include <value.h>
+#include <sheet.h>
 #include <gnumeric-gconf.h>
 
 #include <gsf/gsf-impl-utils.h>
@@ -41,15 +45,15 @@
 #include <gtk/gtk.h>
 #include <string.h>
 
-#undef F_
-#define F_(s) dgettext ("gnumeric-functions", (s))
+#define F2(func,s) dgettext ((func)->textdomain->str, (s))
 
 #define FUNCTION_SELECT_KEY "function-selector-dialog"
 #define FUNCTION_SELECT_DIALOG_KEY "function-selector-dialog"
 
 typedef struct {
 	WBCGtk  *wbcg;
-	Workbook  *wb;
+	Workbook *wb;
+	Sheet *sheet;
 
 	GladeXML  *gui;
 	GtkWidget *dialog;
@@ -80,15 +84,17 @@ enum {
 static void
 dialog_function_load_recent_funcs (FunctionSelectState *state)
 {
-	GnmFunc *fd;
-	GSList const *recent_funcs, *this_funcs;
+	GSList const *recent_funcs;
 
-	recent_funcs = gnm_app_prefs->recent_funcs;
+	for (recent_funcs = gnm_conf_get_functionselector_recentfunctions ();
+	     recent_funcs;
+	     recent_funcs = recent_funcs->next) {
+		char const *name = recent_funcs->data;
+		GnmFunc *fd;
 
-	for (this_funcs = recent_funcs; this_funcs; this_funcs = this_funcs->next) {
-		char const *name = this_funcs->data;
 		if (name == NULL)
 			continue;
+
 		fd = gnm_func_lookup (name, NULL);
 		if (fd)
 			state->recent_funcs = g_slist_prepend (state->recent_funcs, fd);
@@ -100,7 +106,7 @@ dialog_function_write_recent_func (FunctionSelectState *state, GnmFunc const *fd
 {
 	GSList *rec_funcs;
 	GSList *gconf_value_list = NULL;
-	guint ulimit = gnm_app_prefs->num_of_recent_funcs;
+	guint ulimit = gnm_conf_get_functionselector_num_of_recent ();
 
 	state->recent_funcs = g_slist_remove (state->recent_funcs, (gpointer) fd);
 	state->recent_funcs = g_slist_prepend (state->recent_funcs, (gpointer) fd);
@@ -113,8 +119,8 @@ dialog_function_write_recent_func (FunctionSelectState *state, GnmFunc const *fd
 		gconf_value_list = g_slist_prepend
 			(gconf_value_list, g_strdup (gnm_func_get_name (rec_funcs->data)));
 	}
-	gnm_gconf_set_recent_funcs (gconf_value_list);
-	go_conf_sync (NULL);
+	gnm_conf_set_functionselector_recentfunctions (gconf_value_list);
+	go_slist_free_custom (gconf_value_list, g_free);
 }
 
 
@@ -226,113 +232,6 @@ dialog_function_select_load_tree (FunctionSelectState *state)
 }
 
 
-static void
-describe_old_style (GtkTextBuffer *description, GnmFunc const *func)
-{
-	TokenizedHelp *help = tokenized_help_new (func);
-	char const * f_desc = tokenized_help_find (help, "DESCRIPTION");
-	char const *f_syntax = tokenized_help_find (help, "SYNTAX");
-
-	char const * cursor;
-	GString    * buf = g_string_new (NULL);
-	GtkTextIter  start, end;
-	GtkTextTag * tag;
-	int          syntax_length =  g_utf8_strlen (f_syntax,-1);
-
-	g_string_append (buf, f_syntax);
-	g_string_append (buf, "\n\n");
-	g_string_append (buf, f_desc);
-	gtk_text_buffer_set_text (description, buf->str, -1);
-
-	/* Set the syntax Bold */
-	tag = gtk_text_buffer_create_tag (description,
-					  NULL,
-					  "weight",
-					  PANGO_WEIGHT_BOLD,
-					  NULL);
-	gtk_text_buffer_get_iter_at_offset (description,
-					    &start, 0);
-	gtk_text_buffer_get_iter_at_offset (description,
-					    &end, syntax_length);
-	gtk_text_buffer_apply_tag (description, tag,
-				   &start, &end);
-	syntax_length += 2;
-
-	/* Set the arguments and errors Italic */
-	for (cursor = f_desc; *cursor; cursor = g_utf8_next_char (cursor)) {
-		int i;
-		if (*cursor == '@' || *cursor == '#') {
-			int j;
-
-			cursor++;
-			for (i = 0;
-			     *cursor && !g_unichar_isspace (g_utf8_get_char (cursor));
-			     i++)
-				cursor = g_utf8_next_char (cursor);
-
-			j = g_utf8_pointer_to_offset (f_desc, cursor);
-
-			if (i > 0)
-				cursor = g_utf8_prev_char (cursor);
-
-			tag = gtk_text_buffer_create_tag
-				(description,
-				 NULL, "style",
-				 PANGO_STYLE_ITALIC, NULL);
-			gtk_text_buffer_get_iter_at_offset
-				(description, &start,
-				 j - i + syntax_length);
-			gtk_text_buffer_get_iter_at_offset
-				(description, &end,
-				 j + syntax_length);
-			gtk_text_buffer_apply_tag
-				(description, tag,
-				 &start, &end);
-		} else if (*cursor == '\n' &&
-			   cursor[1] == '*' &&
-			   cursor[2] == ' ') {
-			int j = g_utf8_pointer_to_offset (f_desc, cursor);
-			char const *p;
-
-			tag = gtk_text_buffer_create_tag
-				(description, NULL,
-				 "weight", PANGO_WEIGHT_BOLD,
-				 NULL);
-			gtk_text_buffer_get_iter_at_offset
-				(description, &start,
-				 j + 1 + syntax_length);
-			gtk_text_buffer_get_iter_at_offset
-				(description, &end,
-				 j + 2 + syntax_length);
-			gtk_text_buffer_apply_tag
-				(description, tag,
-				 &start, &end);
-
-			/* Make notes to look cooler. */
-			p = cursor + 2;
-			for (i = 0; *p && *p != '\n'; i++)
-				p = g_utf8_next_char (p);
-
-			tag = gtk_text_buffer_create_tag
-				(description, NULL,
-				 "scale", 0.85, NULL);
-
-			gtk_text_buffer_get_iter_at_offset
-				(description,
-				 &start, j + 1 + syntax_length);
-			gtk_text_buffer_get_iter_at_offset
-				(description, &end,
-				 j + i + 1 + syntax_length);
-			gtk_text_buffer_apply_tag
-				(description, tag,
-				 &start, &end);
-		}
-	}
-
-	g_string_free (buf, TRUE);
-	tokenized_help_destroy (help);
-}
-
 static GtkTextTag *
 make_link (GtkTextBuffer *description, const char *name,
 	   GCallback cb, gpointer user)
@@ -396,6 +295,51 @@ cb_link_event (GtkTextTag *link, GObject *trigger,
 	return FALSE;
 }
 
+static char *
+make_expr_example (Sheet *sheet, const char *text, gboolean localized)
+{
+	GnmLocale *oldlocale = NULL;
+	GnmExprTop const *texpr;
+	char *res;
+	GnmParsePos pp;
+	GnmEvalPos ep;
+	GnmConventions const *convs = gnm_conventions_default;
+
+	eval_pos_init_sheet (&ep, sheet);
+	parse_pos_init_evalpos (&pp, &ep);
+
+	if (!localized)
+		oldlocale = gnm_push_C_locale ();
+	texpr = gnm_expr_parse_str (text, &pp,
+				    GNM_EXPR_PARSE_DEFAULT,
+				    convs,
+				    NULL);
+	if (!localized)
+		gnm_pop_C_locale (oldlocale);
+
+	if (texpr) {
+		char *etxt = gnm_expr_top_as_string (texpr, &pp, convs);
+		GnmValue *val = gnm_expr_top_eval
+			(texpr, &ep, GNM_EXPR_EVAL_PERMIT_NON_SCALAR);
+		GnmExprTop const *texpr_res = gnm_expr_top_new_constant (val);
+		char *vtxt = gnm_expr_top_as_string (texpr_res, &pp, convs);
+
+		gnm_expr_top_unref (texpr);
+		gnm_expr_top_unref (texpr_res);
+		
+		res = g_strdup_printf (_("%s evaluates to %s."), etxt, vtxt);
+
+		g_free (etxt);
+		g_free (vtxt);
+	} else {
+		g_warning ("Failed to parse [%s]", text);
+		res = g_strdup ("");
+	}
+
+	return res;
+}
+
+
 
 #define ADD_LTEXT(text,len) gtk_text_buffer_insert (description, &ti, (text), (len))
 #define ADD_TEXT(text) ADD_LTEXT((text),-1)
@@ -406,7 +350,7 @@ cb_link_event (GtkTextTag *link, GObject *trigger,
 			if (at != NULL) { ADD_BOLD_TEXT(t, at - t); t = at + 1; } else {ADD_TEXT (t); break;}}} 
 
 static void
-describe_new_style (GtkTextBuffer *description, GnmFunc const *func)
+describe_new_style (GtkTextBuffer *description, GnmFunc const *func, Sheet *sheet)
 {
 	GnmFuncHelp const *help;
 	GtkTextIter ti;
@@ -424,7 +368,7 @@ describe_new_style (GtkTextBuffer *description, GnmFunc const *func)
 	for (help = func->help; 1; help++) {
 		switch (help->type) {
 		case GNM_FUNC_HELP_NAME: {
-			const char *text = F_(help->text);
+			const char *text = F2 (func, help->text);
 			const char *colon = strchr (text, ':');
 			if (!colon)
 				break;
@@ -435,7 +379,7 @@ describe_new_style (GtkTextBuffer *description, GnmFunc const *func)
 			break;
 		}
 		case GNM_FUNC_HELP_ARG: {
-			const char *text = F_(help->text);
+			const char *text = F2 (func, help->text);
 			const char *colon = strchr (text, ':');
 			if (!colon)
 				break;
@@ -448,19 +392,19 @@ describe_new_style (GtkTextBuffer *description, GnmFunc const *func)
 
 			ADD_BOLD_TEXT (text, colon - text);
 			ADD_TEXT (": ");
-			ADD_TEXT (colon + 1);
+			ADD_TEXT_WITH_ARGS (colon + 1);
 			ADD_TEXT ("\n");
 			break;
 		}
 		case GNM_FUNC_HELP_DESCRIPTION: {
-			const char *text = F_(help->text);
+			const char *text = F2 (func, help->text);
 			ADD_TEXT ("\n");
 			ADD_TEXT_WITH_ARGS (text);
 			ADD_TEXT ("\n");
 			break;
 		}
 		case GNM_FUNC_HELP_NOTE: {
-			const char *text = F_(help->text);
+			const char *text = F2 (func, help->text);
 			ADD_TEXT ("\n");
 			ADD_TEXT (_("Note: "));
 			ADD_TEXT_WITH_ARGS (text);
@@ -468,7 +412,8 @@ describe_new_style (GtkTextBuffer *description, GnmFunc const *func)
 			break;
 		}
 		case GNM_FUNC_HELP_EXAMPLES: {
-			const char *text = help->text;
+			const char *text = F2 (func, help->text);
+			gboolean was_translated = (text != help->text);
 
 			if (!seen_examples) {
 				seen_examples = TRUE;
@@ -477,7 +422,13 @@ describe_new_style (GtkTextBuffer *description, GnmFunc const *func)
 				ADD_TEXT ("\n");
 			}
 
-			ADD_TEXT_WITH_ARGS (text);
+			if (text[0] == '=') {
+				char *example = make_expr_example (sheet, text + 1, was_translated);
+				ADD_TEXT (example);
+				g_free (example);
+			} else {
+				ADD_TEXT_WITH_ARGS (text);
+			}
 			ADD_TEXT ("\n");
 			break;
 		}
@@ -540,6 +491,22 @@ describe_new_style (GtkTextBuffer *description, GnmFunc const *func)
 			seen_extref = TRUE;
 			break;
 		}
+		case GNM_FUNC_HELP_EXCEL: {
+			const char *text = F2 (func, help->text);
+			ADD_TEXT ("\n");
+			ADD_TEXT (_("Microsoft Excel: "));
+			ADD_TEXT_WITH_ARGS (text);
+			ADD_TEXT ("\n");
+			break;
+		}
+		case GNM_FUNC_HELP_ODF: {
+			const char *text = F2 (func, help->text);
+			ADD_TEXT ("\n");
+			ADD_TEXT (_("ODF (OpenFormula): "));
+			ADD_TEXT_WITH_ARGS (text);
+			ADD_TEXT ("\n");
+			break;
+		}
 		default:
 			break;
 		}
@@ -717,7 +684,7 @@ cb_description_clicked (GtkTextBuffer *textbuffer,
 }
 
 static void
-cb_dialog_function_select_fun_selection_changed (GtkTreeSelection *the_selection,
+cb_dialog_function_select_fun_selection_changed (GtkTreeSelection *selection,
 						 FunctionSelectState *state)
 {
 	GtkTreeIter  iter;
@@ -733,7 +700,7 @@ cb_dialog_function_select_fun_selection_changed (GtkTreeSelection *the_selection
 				      0.1, TRUE, 0.0, 0.0);
 	gtk_text_buffer_set_text (description, "", 0);
 
-	if (gtk_tree_selection_get_selected (the_selection, &model, &iter)) {
+	if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
 		gtk_tree_model_get (model, &iter,
 				    FUNCTION, &func,
 				    -1);
@@ -742,10 +709,8 @@ cb_dialog_function_select_fun_selection_changed (GtkTreeSelection *the_selection
 
 		if (func->help == NULL)
 			gtk_text_buffer_set_text (description, "?", -1);
-		else if (func->help[0].type == GNM_FUNC_HELP_OLD)
-			describe_old_style (description, func);
 		else
-			describe_new_style (description, func);
+			describe_new_style (description, func, state->sheet);
 
 		gtk_widget_set_sensitive (state->ok_button, TRUE);
 	} else {
@@ -922,7 +887,8 @@ dialog_function_select (WBCGtk *wbcg, char const *key)
 
 	state = g_new (FunctionSelectState, 1);
 	state->wbcg  = wbcg;
-	state->wb    = wb_control_get_workbook (WORKBOOK_CONTROL (wbcg));
+	state->sheet = wb_control_cur_sheet (WORKBOOK_CONTROL (wbcg));
+	state->wb    = state->sheet->workbook;
         state->gui   = gui;
         state->dialog = glade_xml_get_widget (state->gui, "selection_dialog");
 	state->formula_guru_key = key;
