@@ -84,7 +84,7 @@
 #define GNUMERIC_HELP_LINK_DATA_MERGE "sect-data-generate"
 
 /* dialog-pivottable.c         */
-#define GNUMERIC_HELP_LINK_PIVOT_TABLE ""
+#define GNUMERIC_HELP_LINK_DATA_SLICER "sect-data-slicer-config"
 
 /* dialog-plugin-manager.c     */
 #define GNUMERIC_HELP_LINK_PLUGIN_MANAGER "sect-configuring-plugins"
@@ -146,6 +146,15 @@
 #define GNUMERIC_HELP_LINK_ANOVA_SINGLE_FACTOR "sect-analysis-statistical"
 #define GNUMERIC_HELP_LINK_ANOVA_TWO_FACTOR "sect-analysis-statistical"
 
+/* dialog-analysis-tool-chi-squared.c */
+#define GNUMERIC_HELP_LINK_CHI_SQUARED "sect-analysis-statistical"
+
+/* dialog-analysis-tool-frequency.c */
+#define GNUMERIC_HELP_LINK_FREQUENCY "sect-analysis-statistical"
+
+/* dialog-analysis-tool-kaplan-meier.c */
+#define GNUMERIC_HELP_LINK_KAPLAN_MEIER "sect-analysis-statistical"
+
 /* dialog-consolidate.c     */
 #define GNUMERIC_HELP_LINK_CONSOLIDATE ""
 
