@@ -12,20 +12,20 @@ void functions_init     (void);
 void functions_shutdown (void);
 
 void function_dump_defs (char const *filename, int dump_type);
+int gnm_func_sanity_check (void);
 
 /******************************************************************************/
 /* Function group support */
 
 struct _GnmFuncGroup {
-	GnmString *internal_name, *display_name;
+	GOString *internal_name, *display_name;
 	gboolean has_translation;
 	GSList *functions;
 };
 
 GnmFuncGroup *gnm_func_group_get_nth (gint n);
-GnmFuncGroup *gnm_func_group_fetch     		    (char const *name);
-GnmFuncGroup *gnm_func_group_fetch_with_translation (char const *name,
-						     char const *translation);
+GnmFuncGroup *gnm_func_group_fetch (char const *name,
+				    char const *translation);
 
 /******************************************************************************/
 
@@ -48,11 +48,11 @@ GnmFuncGroup *gnm_func_group_fetch_with_translation (char const *name,
  *  Argument tokens passed in 'args'
  *
  * With intersection and iteration support
- * 	f : float 		(no errors, string conversion attempted)
- * 	b : boolean		(identical to f, Do we need this ?)
- * 	s : string		(no errors)
- * 	S : 'scalar': any non-error value
- * 	E : scalar including errors
+ *	f : float		(no errors, string conversion attempted)
+ *	b : boolean		(identical to f, Do we need this ?)
+ *	s : string		(no errors)
+ *	S : 'scalar': any non-error value
+ *	E : scalar including errors
  * Without intersection or iteration support
  *	r : cell range	content is _NOT_ guaranteed to have been evaluated yet
  *	A : area	either range or array (as above)
@@ -81,7 +81,7 @@ typedef enum {
 	 * unexpectedly when we recalc later.  This probably needs to be done
 	 * on a per import format basis.  It may not belong here.
 	 */
-	GNM_FUNC_RECALC_ONLOAD 		= 1 << 2,
+	GNM_FUNC_RECALC_ONLOAD		= 1 << 2,
 
 	/* an unknown function that will hopefully be defined later */
 	GNM_FUNC_IS_PLACEHOLDER		= 1 << 3,
@@ -123,8 +123,8 @@ typedef enum {
 	GNM_FUNC_TEST_STATUS_UNDER_DEVELOPMENT
 } GnmFuncTestStatus;
 
-typedef GnmValue 	*(*GnmFuncArgs)	  (GnmFuncEvalInfo *ei, GnmValue const * const *args);
-typedef GnmValue 	*(*GnmFuncNodes)  (GnmFuncEvalInfo *ei,
+typedef GnmValue	*(*GnmFuncArgs)	  (GnmFuncEvalInfo *ei, GnmValue const * const *args);
+typedef GnmValue	*(*GnmFuncNodes)  (GnmFuncEvalInfo *ei,
 					   int argc, GnmExprConstPtr const *argv);
 typedef DependentFlags	 (*GnmFuncLink)	  (GnmFuncEvalInfo *ei);
 typedef void		 (*GnmFuncUnlink) (GnmFuncEvalInfo *ei);
@@ -135,13 +135,39 @@ typedef gboolean (*GnmFuncLoadDesc)  (GnmFunc const *f, GnmFuncDescriptor *fd);
 typedef enum {
 	GNM_FUNC_HELP_END,		/* Format */
 					/* ------ */
-	GNM_FUNC_HELP_OLD,		/* old token based format */
-	GNM_FUNC_HELP_NAME,		/* <NAME>:<1 SENTENCE DESCRIPTION>	(translated) */
-	GNM_FUNC_HELP_ARG,		/* <NAME>:<1 SENTENCE DESCRIPTION> 	(translated) */
-	GNM_FUNC_HELP_DESCRIPTION,	/* <LONG DESCRIPTION (reference args using @{arg})> 		(translated) */
-	GNM_FUNC_HELP_NOTE,		/* <SPECIAL CASES (reference args using @{arg})> 		(translated) */
-	GNM_FUNC_HELP_EXAMPLES,		/* <TEXT and EXAMPLES ?? get a hook to enter the sample ?? > 	(translated) */
-	GNM_FUNC_HELP_SEEALSO		/* name,name,name ...			(not translated) */
+	GNM_FUNC_HELP_NAME,
+	/* <NAME>:<1 SENTENCE DESCRIPTION> (translated) */
+
+	GNM_FUNC_HELP_ARG,
+	/* <NAME>:<1 SENTENCE DESCRIPTION> (translated) */
+
+	GNM_FUNC_HELP_DESCRIPTION,
+	/* <LONG DESCRIPTION (reference args using @{arg})> (translated) */
+
+	GNM_FUNC_HELP_NOTE,
+	/* <SPECIAL CASES (reference args using @{arg})> (translated) */
+
+	GNM_FUNC_HELP_EXAMPLES,
+	/*
+	 * Either translated text, or a formula that is only marked for
+	 * translation if it contains strings that need to be translated.
+	 */
+
+	GNM_FUNC_HELP_SEEALSO,
+	/* name,name,name ...	(not translated) */
+
+	GNM_FUNC_HELP_EXTREF,
+	/*
+	 * Link to external descriptions.  The following styles defined:
+	 * wolfram:Sine.html
+	 * wiki:en:Trigonometric_functions
+	 */
+
+	GNM_FUNC_HELP_EXCEL,
+	/* <SPECIAL NOTE RE EXCEL (reference args using @{arg})> (translated) */
+
+	GNM_FUNC_HELP_ODF
+	/* <SPECIAL NOTE RE ODF (reference args using @{arg})> (translated) */
 } GnmFuncHelpType;
 typedef struct {
     GnmFuncHelpType	 type;
@@ -151,7 +177,6 @@ typedef struct {
 struct _GnmFuncDescriptor {
 	char const *name;
 	char const *arg_spec;
-	char const *arg_names;
 	GnmFuncHelp const *help;
 	GnmFuncArgs	  fn_args;
 	GnmFuncNodes	  fn_nodes;
@@ -167,6 +192,7 @@ struct _GnmFunc {
 	char const *name;
 	char const *arg_names;
 	GnmFuncHelp const *help;
+	GOString *textdomain;
 	GnmFuncType fn_type;
 	union {
 		GnmFuncNodes nodes;
@@ -186,8 +212,8 @@ struct _GnmFunc {
 	GnmFuncTestStatus	 test_status;
 	GnmFuncFlags		 flags;
 
-	gint         		 ref_count;
-	gpointer     		 user_data;
+	gint			 ref_count;
+	gpointer		 user_data;
 };
 
 struct _GnmFuncEvalInfo {
@@ -205,15 +231,20 @@ gpointer    gnm_func_get_user_data   (GnmFunc const *func);
 void        gnm_func_set_user_data   (GnmFunc *func, gpointer user_data);
 GnmFunc	   *gnm_func_lookup	     (char const *name, Workbook *scope);	/* change scope one day */
 GnmFunc    *gnm_func_add	     (GnmFuncGroup *group,
-				      GnmFuncDescriptor const *descriptor);
+				      GnmFuncDescriptor const *descriptor,
+				      const char *textdomain);
 GnmFunc    *gnm_func_add_stub	     (GnmFuncGroup *group,
-				      char const *name,
-				      GnmFuncLoadDesc  load_desc,
+				      const char *name,
+				      const char *textdomain,
+				      GnmFuncLoadDesc load_desc,
 				      GnmFuncRefNotify opt_ref_notify);
 GnmFunc    *gnm_func_add_placeholder (Workbook *optional_scope,			/* change scope one day */
 				      char const *name,
 				      char const *type,
 				      gboolean copy_name);
+GnmFunc	   *gnm_func_lookup_or_add_placeholder 
+                                      (char const *name, Workbook *scope,	/* change scope one day */
+				       gboolean copy_name);
 
 /* TODO */
 void        function_def_count_args    (GnmFunc const *fn_def,
