@@ -3,8 +3,7 @@
 # define _GNM_PLUGIN_H_
 
 #include <gnumeric.h>
-#include <goffice/app/goffice-app.h>
-#include <goffice/app/go-plugin.h>
+#include <goffice/goffice.h>
 #include <goffice/app/module-plugin-defs.h>
 #include <gmodule.h>
 #include <libxml/tree.h>
@@ -54,7 +53,7 @@ G_MODULE_EXPORT GOPluginModuleDepend const go_plugin_depends [] = {	\
 	{ "goffice",	GOFFICE_API_VERSION },				\
 	{ "gnumeric",	GNM_VERSION_FULL }				\
 };	\
-G_MODULE_EXPORT GOPluginModuleHeader const go_plugin_header =  		\
+G_MODULE_EXPORT GOPluginModuleHeader const go_plugin_header =		\
 	{ GOFFICE_MODULE_PLUGIN_MAGIC_NUMBER, G_N_ELEMENTS (go_plugin_depends) }
 
 /**************************************************************************/
