@@ -25,10 +25,9 @@
 #include "gnm-so-polygon.h"
 #include "sheet-object-impl.h"
 #include "xml-io.h"
+#include "parse-util.h"
 
-#include <goffice/utils/go-libxml-extras.h>
-#include <goffice/graph/gog-style.h>
-#include <goffice/utils/go-color.h>
+#include <goffice/goffice.h>
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
 #include <string.h>
@@ -47,7 +46,7 @@ attr_eq (const xmlChar *a, const char *s)
 
 typedef struct {
 	SheetObject base;
-	GogStyle *style;
+	GOStyle *style;
 	GArray	 *points;
 } GnmSOPolygon;
 typedef SheetObjectClass GnmSOPolygonClass;
@@ -78,6 +77,9 @@ so_polygon_view_set_bounds (SheetObjectView *sov, double const *coords, gboolean
 			return;
 
 		i = sop->points->len / 2;
+		if (i == 0)
+			return;
+
 		pts = foo_canvas_points_new (i);
 		x_scale = fabs (coords[2] - coords[0]);
 		y_scale = fabs (coords[3] - coords[1]);
@@ -121,15 +123,15 @@ enum {
 	SOP_PROP_POINTS
 };
 
-static GogStyle *
+static GOStyle *
 sop_default_style (void)
 {
-	GogStyle *res = gog_style_new ();
-	res->interesting_fields = GOG_STYLE_OUTLINE | GOG_STYLE_FILL;
+	GOStyle *res = go_style_new ();
+	res->interesting_fields = GO_STYLE_OUTLINE | GO_STYLE_FILL;
 	res->outline.width = 0; /* hairline */
 	res->outline.color = RGBA_BLACK;
 	res->outline.dash_type = GO_LINE_SOLID; /* anything but 0 */
-	res->fill.type = GOG_FILL_STYLE_PATTERN;
+	res->fill.type = GO_STYLE_FILL_PATTERN;
 	go_pattern_set_solid (&res->fill.pattern, RGBA_WHITE);
 	return res;
 }
@@ -141,7 +143,7 @@ sop_default_style (void)
 static void
 cb_gnm_so_polygon_style_changed (FooCanvasItem *view, GnmSOPolygon const *sop)
 {
-	GogStyle const *style = sop->style;
+	GOStyle const *style = sop->style;
 	GdkColor outline_buf, *outline_gdk = NULL;
 	GdkColor fill_buf, *fill_gdk = NULL;
 
@@ -150,7 +152,7 @@ cb_gnm_so_polygon_style_changed (FooCanvasItem *view, GnmSOPolygon const *sop)
 	    style->outline.dash_type != GO_LINE_NONE)
 		outline_gdk = go_color_to_gdk (style->outline.color, &outline_buf);
 
-	if (style->fill.type != GOG_FILL_STYLE_NONE)
+	if (style->fill.type != GO_STYLE_FILL_NONE)
 		fill_gdk = go_color_to_gdk (style->fill.pattern.back, &fill_buf);
 
 	if (style->outline.width > 0.)	/* in pts */
@@ -187,8 +189,8 @@ static void
 gnm_so_polygon_user_config (SheetObject *so, SheetControl *sc)
 {
 	dialog_so_styled (scg_wbcg (SHEET_CONTROL_GUI (sc)), G_OBJECT (so),
-		GNM_SO_POLYGON (so)->style, sop_default_style (),
-		_("Polygon Properties"));
+			  GNM_SO_POLYGON (so)->style, sop_default_style (),
+			  _("Polygon Properties"), SO_STYLED_STYLE_ONLY);
 }
 
 #endif /* GNM_WITH_GTK */
@@ -220,10 +222,25 @@ gnm_so_polygon_read_xml_dom (SheetObject *so, char const *typename,
 }
 
 static void
-gnm_so_polygon_write_xml_sax (SheetObject const *so, GsfXMLOut *output)
+gnm_so_polygon_write_xml_sax (SheetObject const *so, GsfXMLOut *output,
+			      GnmConventions const *convs)
 {
-	/* TODO */
-	gnm_so_polygon_parent_class->write_xml_sax (so, output);
+	GnmSOPolygon const *sop = GNM_SO_POLYGON (so);
+	unsigned int ui;
+	int prec = convs ? convs->output.decimal_digits : -1;
+
+	for (ui = 0; ui + 1 < (sop->points ? sop->points->len : 0); ui += 2) {
+		double x = g_array_index (sop->points, double, ui);
+		double y = g_array_index (sop->points, double, ui + 1);
+		gsf_xml_out_start_element (output, "Point");
+		gsf_xml_out_add_float (output, "x", x, prec);
+		gsf_xml_out_add_float (output, "y", y, prec);
+		gsf_xml_out_end_element (output); /* </Point> */
+	}
+
+	gsf_xml_out_start_element (output, "Style");
+	go_persist_sax_save (GO_PERSIST (sop->style), output);
+	gsf_xml_out_end_element (output); /* </Style> */
 }
 
 static void
@@ -246,19 +263,19 @@ gnm_so_polygon_set_property (GObject *obj, guint param_id,
 {
 	GnmSOPolygon *sop = GNM_SO_POLYGON (obj);
 	GArray *points;
-	GogStyle *style;
+	GOStyle *style;
 
 	switch (param_id) {
 	case SOP_PROP_STYLE:
 		style = sop->style;
 		sop->style = g_object_ref (g_value_get_object (value));
-		sop->style->interesting_fields = GOG_STYLE_OUTLINE | GOG_STYLE_FILL;
+		sop->style->interesting_fields = GO_STYLE_OUTLINE | GO_STYLE_FILL;
 		g_object_unref (style);
 		break;
 	case SOP_PROP_POINTS:
 		points = g_value_get_pointer (value);
-
-		g_return_if_fail (points != NULL);
+		if (!points)
+			points = g_array_new (FALSE, TRUE, sizeof (double));
 
 		if (sop->points != points) {
 			g_array_free (sop->points, TRUE);
@@ -327,7 +344,7 @@ gnm_so_polygon_class_init (GObjectClass *gobject_class)
 	so_class->draw_cairo	= gnm_so_polygon_draw_cairo;
 
         g_object_class_install_property (gobject_class, SOP_PROP_STYLE,
-                 g_param_spec_object ("style", NULL, NULL, GOG_STYLE_TYPE,
+                 g_param_spec_object ("style", NULL, NULL, GO_TYPE_STYLE,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE));
         g_object_class_install_property (gobject_class, SOP_PROP_POINTS,
                  g_param_spec_pointer ("points", NULL, NULL,
