@@ -19,6 +19,8 @@ G_BEGIN_DECLS
 GtkWidget* gnumeric_error_info_dialog_new (ErrorInfo *error);
 void       gnumeric_error_info_dialog_show (GtkWindow *parent,
                                             ErrorInfo *error);
+void       gnumeric_restore_window_geometry (GtkWindow *dialog,
+					     const char *key);
 void       gnumeric_keyed_dialog (WBCGtk *wbcg,
 				  GtkWindow *dialog,
 				  char const *key);
@@ -122,6 +124,11 @@ void gnm_dialog_setup_destroy_handlers (GtkDialog *dialog,
 					WBCGtk *wbcg,
 					GnmDialogDestroyOptions what);
 
+void gnm_canvas_get_position (FooCanvas *canvas, int *x, int *y,
+			      int px, int py);
+
+gboolean gnm_check_for_plugins_missing (char const **ids, GtkWindow *parent);
+
 G_END_DECLS
 
 #endif /* _GNM_GUI_UTIL_H_ */
