@@ -20,13 +20,12 @@
 #endif
 
 #include "command-context.h"
-#include <goffice/app/io-context.h>
+#include <goffice/goffice.h>
 #include "io-context-gtk.h"
 /* TODO: Get rid of this one */
 #include "command-context-stderr.h"
 #include "wbc-gtk-impl.h"
 #include "workbook-view.h"
-#include <goffice/app/go-plugin.h>
 #include "workbook.h"
 #include "gui-file.h"
 #include "gnumeric-gconf.h"
@@ -36,11 +35,10 @@
 #include "gutils.h"
 #include "gnm-plugin.h"
 #include "application.h"
+#include "func.h"
 
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
-#include <goffice/utils/go-file.h>
-#include <goffice/app/go-cmd-context.h>
 
 #include <sys/types.h>
 #include <fcntl.h>
@@ -64,8 +62,10 @@ static gboolean split_funcdocs = FALSE;
 static gboolean immediate_exit_flag = FALSE;
 static gboolean gnumeric_no_splash = FALSE;
 static gboolean gnumeric_no_warnings = FALSE;
+static gboolean func_sanity_check = FALSE;
 static gchar  *func_def_file = NULL;
 static gchar  *func_state_file = NULL;
+static gchar  *ext_refs_file = NULL;
 static gchar  *geometry = NULL;
 static gchar **startup_files;
 
@@ -97,12 +97,22 @@ static const GOptionEntry gnumeric_options [] = {
 		N_("Dumps the function definitions"),
 		N_("FILE")
 	},
+	{
+		"ext-refs-file", 0,
+		G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_FILENAME, &ext_refs_file,
+		N_("Dumps web page for function help"),
+		N_("FILE")
+	},
 	{
 		"split-func", 0,
 		G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, &split_funcdocs,
 		N_("Generate new help and po files"),
 		NULL
 	},
+	{ "func-sanity-check", 0, 0, G_OPTION_ARG_NONE, &func_sanity_check,
+		N_("Sanity check functions' help texts"),
+		NULL
+	},
 	{
 		"quit", 0,
 		G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, &immediate_exit_flag,
@@ -241,7 +251,7 @@ static void
 store_plugin_state (void)
 {
 	GSList *active_plugins = go_plugins_get_active_plugins ();
-	gnm_gconf_set_active_plugins (active_plugins);
+	gnm_conf_set_plugins_active (active_plugins);
 	g_slist_free (active_plugins);
 }
 
@@ -339,7 +349,7 @@ main (int argc, char const **argv)
 		gnm_session_init (argv[0]);
 	}
 
-	gnm_init (TRUE);
+	gnm_init ();
 
 	if (with_gui) {
 		ioc = IO_CONTEXT
@@ -362,6 +372,10 @@ main (int argc, char const **argv)
 		return gnm_dump_func_defs (func_def_file, 1);
 	if (split_funcdocs)
 		return gnm_dump_func_defs (NULL, 2);
+	if (ext_refs_file)
+		return gnm_dump_func_defs (ext_refs_file, 4);
+	if (func_sanity_check)
+		return gnm_func_sanity_check ();
 
 	/* Keep in sync with .desktop file */
 	g_set_application_name (_("Gnumeric Spreadsheet"));
@@ -425,10 +439,10 @@ main (int argc, char const **argv)
 	if (!initial_workbook_open_complete) {
 		initial_workbook_open_complete = TRUE;
 		if (!opened_workbook) {
-			gint n_of_sheets = gnm_app_prefs->initial_sheet_number;
+			gint n_of_sheets = gnm_conf_get_core_workbook_n_sheet ();
 			wbc_gtk_new (NULL,
 				workbook_new_with_sheets (n_of_sheets),
-				NULL, NULL);
+				NULL, geometry);
 		}
 
 		if (immediate_exit_flag) {
