@@ -25,10 +25,7 @@
 #include "value.h"
 #include "mathfunc.h"
 #include "numbers.h"
-#include <goffice/utils/regutf8.h>
-#include <goffice/utils/datetime.h>
-#include <goffice/utils/go-glib-extras.h>
-#include <goffice/utils/go-locale.h>
+#include <goffice/goffice.h>
 
 #include <stdio.h>
 #include <string.h>
