@@ -318,7 +318,7 @@ ensure_decoration_layout (GtkPrintContext   *context)
 	PangoLayout *layout;
 
 	layout = gtk_print_context_create_pango_layout (context);
-	style = gnm_style_dup (gnm_app_prefs->printer_decoration_font);
+	style = gnm_conf_get_printer_decoration_font ();
 	font = gnm_style_get_font
 		(style,
 		 pango_layout_get_context (layout),
@@ -953,9 +953,18 @@ compute_sheet_pages (GtkPrintContext   *context,
 	repeat_left_start = repeat_left_use ? r.start.col : 0;
 	repeat_left_end = repeat_left_use ? r.end.col : 0;
 
-	if (pi->ignore_pb) {
-		gnm_page_breaks_clean (pinfo->page_breaks.h);
-		gnm_page_breaks_clean (pinfo->page_breaks.v);
+	if (!pi->ignore_pb) {
+		if (pinfo->page_breaks.h == NULL)
+		        print_info_set_breaks (pinfo, 
+					       gnm_page_breaks_new (FALSE));
+		else
+			gnm_page_breaks_clean (pinfo->page_breaks.h);
+		if (pinfo->page_breaks.v == NULL)
+		        print_info_set_breaks (pinfo, 
+					       gnm_page_breaks_new (TRUE));
+		else
+			gnm_page_breaks_clean (pinfo->page_breaks.v);
+
 	}
 
 	if (pinfo->scaling.type == PRINT_SCALE_FIT_PAGES) {
@@ -995,15 +1004,6 @@ compute_sheet_pages (GtkPrintContext   *context,
 	usable_x   = page_width / px;
 	usable_y   = page_height / py;
 
-	if (!pi->ignore_pb) {
-		if (pinfo->page_breaks.h == NULL)
-		        print_info_set_breaks (pinfo, 
-					       gnm_page_breaks_new (FALSE));
-		if (pinfo->page_breaks.v == NULL)
-		        print_info_set_breaks (pinfo, 
-					       gnm_page_breaks_new (TRUE));
-	}
-
 	paginate (&column_pagination, sheet, r.start.col, r.end.col,
 		  usable_x - row_header_width,
 		  repeat_left_use, repeat_left_start, repeat_left_end,
@@ -1555,9 +1555,7 @@ gnm_print_sheet (WorkbookControl *wbc, Sheet *sheet,
   pi->wbc = wbc ? WORKBOOK_CONTROL (wbc) : NULL;
   pi->sheet = sheet;
 
-  gnm_gconf_init_printer_defaults ();
-
-  settings = gnm_gconf_get_print_settings ();
+  settings = gnm_conf_get_print_settings ();
   gtk_print_settings_set_int (settings, GNUMERIC_PRINT_SETTING_PRINTRANGE_KEY,
 			      default_range);
   pi->pr = default_range;
@@ -1611,7 +1609,7 @@ gnm_print_sheet (WorkbookControl *wbc, Sheet *sheet,
 
   switch (res) {
   case GTK_PRINT_OPERATION_RESULT_APPLY:
-	  gnm_gconf_set_print_settings (gtk_print_operation_get_print_settings (print));
+	  gnm_conf_set_print_settings (gtk_print_operation_get_print_settings (print));
 	  break;
   case GTK_PRINT_OPERATION_RESULT_CANCEL:
 	  printing_instance_delete (pi);
