@@ -48,9 +48,7 @@
 #include "commands.h"
 #include "gnm-format.h"
 
-#include <goffice/gtk/go-combo-text.h>
-#include <goffice/utils/go-libxml-extras.h>
-#include <goffice/utils/go-glib-extras.h>
+#include <goffice/goffice.h>
 
 #include <gsf/gsf-impl-utils.h>
 #include <libxml/globals.h>
@@ -268,7 +266,9 @@ read_dep (GnmDependent *dep, char const *name,
 		GnmParsePos pos;
 
 		parse_pos_init_sheet (&pos, context->sheet);
-		dep->texpr = gnm_expr_parse_str_simple (CC2XML (txt), &pos);
+		dep->texpr = gnm_expr_parse_str
+			(CC2XML (txt), &pos, GNM_EXPR_PARSE_DEFAULT,
+			 sheet_get_conventions (pos.sheet), NULL);
 		xmlFree (txt);
 	}
 }
@@ -447,7 +447,7 @@ cb_frame_config_ok_clicked (GtkWidget *button, FrameConfigState *state)
 	gchar const *text = gtk_entry_get_text(GTK_ENTRY(state->label));
 
 	cmd_so_set_frame_label (WORKBOOK_CONTROL (state->wbcg),
-				SHEET_OBJECT (state->swf), 
+				SHEET_OBJECT (state->swf),
 				g_strdup (state->old_label), g_strdup (text));
 	gtk_widget_destroy (state->dialog);
 }
@@ -774,6 +774,8 @@ SOW_MAKE_TYPE (button, Button,
 #define SHEET_WIDGET_ADJUSTMENT_TYPE	(sheet_widget_adjustment_get_type())
 #define SHEET_WIDGET_ADJUSTMENT(obj)	(G_TYPE_CHECK_INSTANCE_CAST ((obj), SHEET_WIDGET_ADJUSTMENT_TYPE, SheetWidgetAdjustment))
 #define DEP_TO_ADJUSTMENT(d_ptr)	(SheetWidgetAdjustment *)(((char *)d_ptr) - G_STRUCT_OFFSET(SheetWidgetAdjustment, dep))
+#define SHEET_WIDGET_ADJUSTMENT_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), SHEET_WIDGET_ADJUSTMENT_TYPE, SheetWidgetAdjustmentClass))
+#define SWA_CLASS(so)		     (SHEET_WIDGET_ADJUSTMENT_CLASS (G_OBJECT_GET_CLASS(so)))
 
 typedef struct {
 	SheetObjectWidget	sow;
@@ -781,8 +783,19 @@ typedef struct {
 	gboolean  being_updated;
 	GnmDependent dep;
 	GtkAdjustment *adjustment;
+
+	gboolean horizontal;
 } SheetWidgetAdjustment;
-typedef SheetObjectWidgetClass SheetWidgetAdjustmentClass;
+
+typedef struct {
+	SheetObjectWidgetClass parent_class;
+	GType htype, vtype;
+} SheetWidgetAdjustmentClass;
+
+enum {
+	SWA_PROP_0 = 0,
+	SWA_PROP_HORIZONTAL
+};
 
 static GType sheet_widget_adjustment_get_type (void);
 
@@ -818,7 +831,7 @@ sheet_widget_adjustment_get_link (SheetObject *so)
 {
 	SheetWidgetAdjustment *swa = SHEET_WIDGET_ADJUSTMENT (so);
 	GnmExprTop const *texpr = swa->dep.texpr;
-	
+
 	if (texpr)
 		gnm_expr_top_ref (texpr);
 
@@ -876,18 +889,71 @@ cb_adjustment_widget_value_changed (GtkWidget *widget,
 }
 
 static void
-sheet_widget_adjustment_init_full (SheetWidgetAdjustment *swa, GnmCellRef const *ref)
+sheet_widget_adjustment_set_horizontal (SheetWidgetAdjustment *swa,
+					gboolean horizontal)
+{
+	GList *ptr;
+
+	horizontal = !!horizontal;
+	if (horizontal == swa->horizontal)
+		return;
+	swa->horizontal = horizontal;
+
+	/* Change direction for all realized widgets.  */
+	for (ptr = swa->sow.realized_list; ptr != NULL; ptr = ptr->next) {
+		FooCanvasItem *item = FOO_CANVAS_ITEM (ptr->data);
+		GtkWidget *neww =
+			SOW_CLASS (swa)->create_widget (SHEET_OBJECT (swa));
+		gtk_widget_show (neww);
+		foo_canvas_item_set (item, "widget", neww, NULL);
+	}
+}
+
+
+static void
+sheet_widget_adjustment_get_property (GObject *obj, guint param_id,
+				      GValue  *value, GParamSpec *pspec)
+{
+	SheetWidgetAdjustment *swa = SHEET_WIDGET_ADJUSTMENT (obj);
+
+	switch (param_id) {
+	case SWA_PROP_HORIZONTAL:
+		g_value_set_boolean (value, swa->horizontal);
+		break;
+	default :
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
+		break;
+	}
+}
+
+static void
+sheet_widget_adjustment_set_property (GObject *obj, guint param_id,
+				      GValue const *value, GParamSpec *pspec)
+{
+	SheetWidgetAdjustment *swa = SHEET_WIDGET_ADJUSTMENT (obj);
+
+	switch (param_id) {
+	case SWA_PROP_HORIZONTAL:
+		sheet_widget_adjustment_set_horizontal (swa, g_value_get_boolean (value));
+		/* FIXME */
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
+		return;
+	}
+}
+
+static void
+sheet_widget_adjustment_init_full (SheetWidgetAdjustment *swa,
+				   GnmCellRef const *ref,
+				   gboolean horizontal)
 {
 	g_return_if_fail (swa != NULL);
 
 	swa->adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0., 0., 100., 1., 10., 0.));
-#if GLIB_CHECK_VERSION(2,10,0) && GTK_CHECK_VERSION(2,8,14)
 	g_object_ref_sink (swa->adjustment);
-#else
-	g_object_ref (swa->adjustment);
-	gtk_object_sink (GTK_OBJECT (swa->adjustment));
-#endif
 
+	swa->horizontal = horizontal;
 	swa->being_updated = FALSE;
 	swa->dep.sheet = NULL;
 	swa->dep.flags = adjustment_get_dep_type ();
@@ -899,7 +965,9 @@ sheet_widget_adjustment_init_full (SheetWidgetAdjustment *swa, GnmCellRef const
 static void
 sheet_widget_adjustment_init (SheetWidgetAdjustment *swa)
 {
-	sheet_widget_adjustment_init_full (swa, NULL);
+	SheetWidgetAdjustmentClass *klass = SWA_CLASS (swa);
+	gboolean horizontal = (klass->vtype == G_TYPE_NONE);
+	sheet_widget_adjustment_init_full (swa, NULL, horizontal);
 }
 
 static void
@@ -926,7 +994,9 @@ sheet_widget_adjustment_copy (SheetObject *dst, SheetObject const *src)
 	GtkAdjustment *dst_adjust, *src_adjust;
 	GnmCellRef ref;
 
-	sheet_widget_adjustment_init_full (dst_swa, so_get_ref (src, &ref, FALSE));
+	sheet_widget_adjustment_init_full (dst_swa,
+					   so_get_ref (src, &ref, FALSE),
+					   src_swa->horizontal);
 	dst_adjust = dst_swa->adjustment;
 	src_adjust = src_swa->adjustment;
 
@@ -940,12 +1010,14 @@ sheet_widget_adjustment_copy (SheetObject *dst, SheetObject const *src)
 typedef struct {
 	GladeXML           *gui;
 	GtkWidget          *dialog;
-	GnmExprEntry  *expression;
+	GnmExprEntry       *expression;
 	GtkWidget          *min;
 	GtkWidget          *max;
 	GtkWidget          *inc;
 	GtkWidget          *page;
-	
+	GtkWidget          *direction_h;
+	GtkWidget          *direction_v;
+
 	char               *undo_label;
 	GtkWidget          *old_focus;
 
@@ -995,13 +1067,19 @@ static void
 cb_adjustment_config_ok_clicked (GtkWidget *button, AdjustmentConfigState *state)
 {
 	SheetObject *so = SHEET_OBJECT (state->swa);
-	GnmParsePos  pp;
+	GnmParsePos pp;
 	GnmExprTop const *texpr = gnm_expr_entry_parse (state->expression,
 		parse_pos_init_sheet (&pp, so->sheet),
 		NULL, FALSE, GNM_EXPR_PARSE_DEFAULT);
+	gboolean horizontal;
 
-	cmd_so_set_adjustment (WORKBOOK_CONTROL (state->wbcg), so, 
+	horizontal = state->direction_h
+		? gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (state->direction_h))
+		: state->swa->horizontal;
+
+	cmd_so_set_adjustment (WORKBOOK_CONTROL (state->wbcg), so,
 			       texpr,
+			       horizontal,
 			       gtk_spin_button_get_value_as_int (
 				       GTK_SPIN_BUTTON (state->min)),
 			       gtk_spin_button_get_value_as_int (
@@ -1025,11 +1103,12 @@ static void
 sheet_widget_adjustment_user_config_impl (SheetObject *so, SheetControl *sc, char const *undo_label, char const *dialog_label)
 {
 	SheetWidgetAdjustment *swa = SHEET_WIDGET_ADJUSTMENT (so);
-	WBCGtk   *wbcg = scg_wbcg (SHEET_CONTROL_GUI (sc));
+	SheetWidgetAdjustmentClass *swa_class = SWA_CLASS (swa);
+	WBCGtk *wbcg = scg_wbcg (SHEET_CONTROL_GUI (sc));
 	AdjustmentConfigState *state;
 	GtkWidget *table;
-
-	g_return_if_fail (swa != NULL);
+	gboolean has_directions = (swa_class->htype != G_TYPE_NONE &&
+				   swa_class->vtype != G_TYPE_NONE);
 
 	/* Only pop up one copy per workbook */
 	if (gnumeric_dialog_raise_if_exists (wbcg, SHEET_OBJECT_CONFIG_KEY))
@@ -1063,6 +1142,21 @@ sheet_widget_adjustment_user_config_impl (SheetObject *so, SheetControl *sc, cha
 			  0, 0);
 	gtk_widget_show (GTK_WIDGET (state->expression));
 
+	if (has_directions) {
+		state->direction_h = glade_xml_get_widget (state->gui, "direction_h");
+		state->direction_v = glade_xml_get_widget (state->gui, "direction_v");
+		gtk_toggle_button_set_active
+			(GTK_TOGGLE_BUTTON (swa->horizontal
+					    ? state->direction_h
+					    : state->direction_v),
+			 TRUE);
+	} else {
+		state->direction_h = NULL;
+		state->direction_v = NULL;
+		gtk_widget_destroy (glade_xml_get_widget (state->gui, "direction_label"));
+		gtk_widget_destroy (glade_xml_get_widget (state->gui, "direction_box"));
+	}
+
 	/* TODO : This is silly, no need to be similar to XL here. */
 	state->min = glade_xml_get_widget (state->gui, "spin_min");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (state->min), swa->adjustment->lower);
@@ -1140,11 +1234,17 @@ sheet_widget_adjustment_write_xml_sax (SheetObject const *so, GsfXMLOut *output,
 				       GnmConventions const *convs)
 {
 	SheetWidgetAdjustment const *swa = SHEET_WIDGET_ADJUSTMENT (so);
+	SheetWidgetAdjustmentClass *swa_class = SWA_CLASS (so);
+
 	gsf_xml_out_add_float (output, "Min",   swa->adjustment->lower, 2);
 	gsf_xml_out_add_float (output, "Max",   swa->adjustment->upper, 2); /* allow scrolling to max */
 	gsf_xml_out_add_float (output, "Inc",   swa->adjustment->step_increment, 2);
 	gsf_xml_out_add_float (output, "Page",  swa->adjustment->page_increment, 2);
 	gsf_xml_out_add_float (output, "Value", swa->adjustment->value, 2);
+
+	if (swa_class->htype != G_TYPE_NONE && swa_class->vtype != G_TYPE_NONE)
+		gsf_xml_out_add_bool (output, "Horizontal", swa->horizontal);
+
 	sax_write_dep (output, &swa->dep, "Input", convs);
 }
 
@@ -1154,9 +1254,12 @@ sheet_widget_adjustment_prep_sax_parser (SheetObject *so, GsfXMLIn *xin,
 					 GnmConventions const *convs)
 {
 	SheetWidgetAdjustment *swa = SHEET_WIDGET_ADJUSTMENT (so);
+	SheetWidgetAdjustmentClass *swa_class = SWA_CLASS (so);
+	swa->horizontal = (swa_class->vtype == G_TYPE_NONE);
 
 	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2) {
 		double tmp;
+		gboolean b;
 
 		if (gnm_xml_attr_double (attrs, "Min", &tmp))
 			swa->adjustment->lower = tmp;
@@ -1170,6 +1273,10 @@ sheet_widget_adjustment_prep_sax_parser (SheetObject *so, GsfXMLIn *xin,
 			swa->adjustment->value = tmp;
 		else if (sax_read_dep (attrs, "Input", &swa->dep, xin, convs))
 			;
+		else if (swa_class->htype != G_TYPE_NONE &&
+			 swa_class->vtype != G_TYPE_NONE &&
+			 gnm_xml_attr_bool (attrs, "Horizontal", &b))
+			swa->horizontal = b;
 	}
 
 	swa->dep.flags = adjustment_get_dep_type ();
@@ -1182,7 +1289,11 @@ sheet_widget_adjustment_read_xml_dom (SheetObject *so, char const *typename,
 				      xmlNodePtr tree)
 {
 	SheetWidgetAdjustment *swa = SHEET_WIDGET_ADJUSTMENT (so);
+	SheetWidgetAdjustmentClass *swa_class = SWA_CLASS (so);
 	double tmp;
+	gboolean b;
+
+	swa->horizontal = (swa_class->vtype == G_TYPE_NONE);
 
 	read_dep (&swa->dep, "Input", tree, context);
 	swa->dep.flags = adjustment_get_dep_type ();
@@ -1197,6 +1308,11 @@ sheet_widget_adjustment_read_xml_dom (SheetObject *so, char const *typename,
 		swa->adjustment->page_increment = tmp;
 	if (xml_node_get_double  (tree, "Value", &tmp))
 		swa->adjustment->value = tmp;
+	if (swa_class->htype != G_TYPE_NONE &&
+	    swa_class->vtype != G_TYPE_NONE &&
+	    xml_node_get_bool (tree, "Horizontal", &b))
+		swa->horizontal = b;
+
 	gtk_adjustment_changed	(swa->adjustment);
 
 	return FALSE;
@@ -1237,32 +1353,32 @@ SOW_MAKE_TYPE (adjustment, Adjustment,
 	       sheet_widget_adjustment_read_xml_dom,
 	       sheet_widget_adjustment_write_xml_sax,
 	       sheet_widget_adjustment_prep_sax_parser,
-	       NULL,
-	       NULL,
-	       {})
+	       sheet_widget_adjustment_get_property,
+	       sheet_widget_adjustment_set_property,
+	       {
+		       g_object_class_install_property
+			       (object_class, SWA_PROP_HORIZONTAL,
+				g_param_spec_boolean ("horizontal", NULL, NULL,
+						      FALSE,
+						      GSF_PARAM_STATIC | G_PARAM_READWRITE));
+	       })
 
 /****************************************************************************/
 #define SHEET_WIDGET_SCROLLBAR_TYPE	(sheet_widget_scrollbar_get_type ())
 #define SHEET_WIDGET_SCROLLBAR(obj)	(G_TYPE_CHECK_INSTANCE_CAST((obj), SHEET_WIDGET_SCROLLBAR_TYPE, SheetWidgetScrollbar))
 #define DEP_TO_SCROLLBAR(d_ptr)		(SheetWidgetScrollbar *)(((char *)d_ptr) - G_STRUCT_OFFSET(SheetWidgetScrollbar, dep))
 
-typedef SheetWidgetAdjustment		SheetWidgetScrollbar;
-typedef SheetWidgetAdjustmentClass	SheetWidgetScrollbarClass;
+typedef SheetWidgetAdjustment  SheetWidgetScrollbar;
+typedef SheetWidgetAdjustmentClass SheetWidgetScrollbarClass;
 
 static GtkWidget *
 sheet_widget_scrollbar_create_widget (SheetObjectWidget *sow)
 {
-	SheetObject *so = SHEET_OBJECT (sow);
 	SheetWidgetAdjustment *swa = SHEET_WIDGET_ADJUSTMENT (sow);
 	GtkWidget *bar;
 
-	/* TODO : this is not exactly accurate, but should catch the worst of it
-	 * However we do not have a way to handle resizes.
-	 */
-	gboolean is_horizontal = range_width (&so->anchor.cell_bound) > range_height (&so->anchor.cell_bound);
-
 	swa->being_updated = TRUE;
-	bar = is_horizontal
+	bar = swa->horizontal
 		? gtk_hscrollbar_new (swa->adjustment)
 		: gtk_vscrollbar_new (swa->adjustment);
 	GTK_WIDGET_UNSET_FLAGS (bar, GTK_CAN_FOCUS);
@@ -1284,8 +1400,12 @@ sheet_widget_scrollbar_user_config (SheetObject *so, SheetControl *sc)
 static void
 sheet_widget_scrollbar_class_init (SheetObjectWidgetClass *sow_class)
 {
+	SheetWidgetAdjustmentClass *swa_class = (SheetWidgetAdjustmentClass *)sow_class;
+
         sow_class->create_widget = &sheet_widget_scrollbar_create_widget;
 	SHEET_OBJECT_CLASS (sow_class)->user_config = &sheet_widget_scrollbar_user_config;
+	swa_class->htype = GTK_TYPE_HSCROLLBAR;
+	swa_class->vtype = GTK_TYPE_VSCROLLBAR;
 }
 
 GSF_CLASS (SheetWidgetScrollbar, sheet_widget_scrollbar,
@@ -1327,8 +1447,13 @@ sheet_widget_spinbutton_user_config (SheetObject *so, SheetControl *sc)
 static void
 sheet_widget_spinbutton_class_init (SheetObjectWidgetClass *sow_class)
 {
+	SheetWidgetAdjustmentClass *swa_class = (SheetWidgetAdjustmentClass *)sow_class;
+
         sow_class->create_widget = &sheet_widget_spinbutton_create_widget;
 	SHEET_OBJECT_CLASS (sow_class)->user_config = &sheet_widget_spinbutton_user_config;
+
+	swa_class->htype = GTK_TYPE_SPIN_BUTTON;
+	swa_class->vtype = G_TYPE_NONE;
 }
 
 GSF_CLASS (SheetWidgetSpinbutton, sheet_widget_spinbutton,
@@ -1346,16 +1471,11 @@ typedef SheetWidgetAdjustmentClass	SheetWidgetSliderClass;
 static GtkWidget *
 sheet_widget_slider_create_widget (SheetObjectWidget *sow)
 {
-	SheetObject *so = SHEET_OBJECT (sow);
 	SheetWidgetAdjustment *swa = SHEET_WIDGET_ADJUSTMENT (sow);
 	GtkWidget *slider;
-	/* TODO : this is not exactly accurate, but should catch the worst of it
-	 * However we do not have a way to handle resizes.
-	 */
-	gboolean is_horizontal = range_width (&so->anchor.cell_bound) > range_height (&so->anchor.cell_bound);
 
 	swa->being_updated = TRUE;
-	slider = is_horizontal
+	slider = swa->horizontal
 		? gtk_hscale_new (swa->adjustment)
 		: gtk_vscale_new (swa->adjustment);
 	gtk_scale_set_draw_value (GTK_SCALE (slider), FALSE);
@@ -1378,8 +1498,13 @@ sheet_widget_slider_user_config (SheetObject *so, SheetControl *sc)
 static void
 sheet_widget_slider_class_init (SheetObjectWidgetClass *sow_class)
 {
+	SheetWidgetAdjustmentClass *swa_class = (SheetWidgetAdjustmentClass *)sow_class;
+
         sow_class->create_widget = &sheet_widget_slider_create_widget;
 	SHEET_OBJECT_CLASS (sow_class)->user_config = &sheet_widget_slider_user_config;
+
+	swa_class->htype = GTK_TYPE_HSCALE;
+	swa_class->vtype = GTK_TYPE_VSCALE;
 }
 
 GSF_CLASS (SheetWidgetSlider, sheet_widget_slider,
@@ -1644,7 +1769,7 @@ cb_checkbox_config_ok_clicked (GtkWidget *button, CheckboxConfigState *state)
 		NULL, FALSE, GNM_EXPR_PARSE_DEFAULT);
 	gchar const *text = gtk_entry_get_text(GTK_ENTRY(state->label));
 
-	cmd_so_set_checkbox (WORKBOOK_CONTROL (state->wbcg), so, 
+	cmd_so_set_checkbox (WORKBOOK_CONTROL (state->wbcg), so,
 			     texpr, g_strdup (state->old_label), g_strdup (text));
 
 	gtk_widget_destroy (state->dialog);
@@ -1826,7 +1951,7 @@ sheet_widget_checkbox_get_link	 (SheetObject *so)
 {
 	SheetWidgetCheckbox *swc = SHEET_WIDGET_CHECKBOX (so);
 	GnmExprTop const *texpr = swc->dep.texpr;
-	
+
 	if (texpr)
 		gnm_expr_top_ref (texpr);
 
@@ -2211,7 +2336,7 @@ list_content_eval (GnmDependent *dep)
 	if (dep->texpr != NULL) {
 		v = gnm_expr_top_eval (dep->texpr,
 				       eval_pos_init_dep (&ep, dep),
-				       GNM_EXPR_EVAL_PERMIT_NON_SCALAR | 
+				       GNM_EXPR_EVAL_PERMIT_NON_SCALAR |
 				       GNM_EXPR_EVAL_PERMIT_EMPTY);
 	}
 	model = gtk_list_store_new (1, G_TYPE_STRING);
