@@ -5,7 +5,7 @@
 #include "gnumeric.h"
 #include <gtk/gtk.h>
 #include <gsf/gsf-output.h>
-#include <goffice/utils/go-undo.h>
+#include <goffice/goffice.h>
 
 G_BEGIN_DECLS
 
@@ -20,10 +20,10 @@ typedef enum {
 	GOD_ANCHOR_DIR_DOWN_RIGHT = 0x11,
 
 	GOD_ANCHOR_DIR_NONE_MASK  = 0x00,
-	GOD_ANCHOR_DIR_H_MASK 	  = 0x01,
+	GOD_ANCHOR_DIR_H_MASK	  = 0x01,
 	GOD_ANCHOR_DIR_RIGHT	  = 0x01,
 	GOD_ANCHOR_DIR_V_MASK	  = 0x10,
-	GOD_ANCHOR_DIR_DOWN  	  = 0x10
+	GOD_ANCHOR_DIR_DOWN	  = 0x10
 } GODrawingAnchorDir;
 typedef struct _GODrawingAnchor {
 	int			pos_pts [4];	/* position in points */
@@ -106,18 +106,18 @@ gboolean sheet_object_rubber_band_directly (SheetObject const *so);
 /* Anchor utilities */
 void sheet_object_anchor_to_pts	(SheetObjectAnchor const *anchor,
 				 Sheet const *sheet, double *res_pts);
+void sheet_object_anchor_to_offset_pts	(SheetObjectAnchor const *anchor,
+					 Sheet const *sheet, double *res_pts);
 void sheet_object_anchor_init	(SheetObjectAnchor *anchor,
 				 GnmRange const *cell_bound,
 				 float const	*offset,
 				 GODrawingAnchorDir direction);
 SheetObjectAnchor *
      sheet_object_anchor_dup	(SheetObjectAnchor const *src);
-void sheet_object_anchor_assign	(SheetObjectAnchor *dst,
-				 SheetObjectAnchor const *src);
 
 /* Image rendering */
 GtkTargetList *sheet_object_get_target_list (SheetObject const *so);
-void sheet_object_write_image 	(SheetObject const *so,
+void sheet_object_write_image	(SheetObject const *so,
 				 char const *format,
 				 double resolution,
 				 GsfOutput *output,
@@ -125,7 +125,7 @@ void sheet_object_write_image 	(SheetObject const *so,
 
 /* Object export */
 GtkTargetList *sheet_object_exportable_get_target_list (SheetObject const *so);
-void sheet_object_write_object 	(SheetObject const *so,
+void sheet_object_write_object	(SheetObject const *so,
 				 char const *format,
 				 GsfOutput *output, GError **err,
 				 GnmConventions const *convs);
