@@ -16,6 +16,10 @@
 #include "position.h"
 #include "parse-util.h"
 #include "workbook.h"
+#include "workbook-priv.h"
+#include "sheet.h"
+#include "dependent.h"
+#include "expr-name.h"
 #include "libgnumeric.h"
 #include "gutils.h"
 #include "gnumeric-paths.h"
@@ -24,12 +28,7 @@
 #include "command-context-stderr.h"
 #include "workbook-view.h"
 #include <dialogs/dialogs.h>
-#include <goffice/app/file.h>
-#include <goffice/app/io-context.h>
-#include <goffice/app/error-info.h>
-#include <goffice/app/go-doc.h>
-#include <goffice/app/go-cmd-context.h>
-#include <goffice/utils/go-file.h>
+#include <goffice/goffice.h>
 #include <gsf/gsf-utils.h>
 #include <string.h>
 #ifdef HAVE_SYS_RESOURCE_H
@@ -46,6 +45,7 @@ static char *ssconvert_import_encoding = NULL;
 static char *ssconvert_import_id = NULL;
 static char *ssconvert_export_id = NULL;
 static char *ssconvert_export_options = NULL;
+static char *ssconvert_merge_target = NULL;
 static char **ssconvert_goal_seek = NULL;
 
 static const GOptionEntry ssconvert_options [] = {
@@ -81,6 +81,13 @@ static const GOptionEntry ssconvert_options [] = {
 
 	/* ---------------------------------------- */
 
+	{
+		"merge-to", 'M',
+		0, G_OPTION_ARG_STRING, &ssconvert_merge_target,
+		N_("Merge listed files (all same format) to make this file"),
+		N_("file")
+	},
+
 	{
 		"export-type", 'T',
 		0, G_OPTION_ARG_STRING, &ssconvert_export_id,
@@ -225,8 +232,186 @@ list_them (get_them_f get_them,
 	}
 }
 
+/*
+ * Read the files we're going to merge and return a list of Workbooks.
+ */
+static GSList *
+read_files_to_merge (const char *inputs[], GOFileOpener *fo,
+		     IOContext *io_context, GOCmdContext *cc)
+{
+	GSList *wbs = NULL;
+
+	while (*inputs) {
+		const char *fname = *inputs;
+		char *uri = go_shell_arg_to_uri (fname);
+		WorkbookView *wbv =
+			wb_view_new_from_uri (uri, fo, io_context,
+					      ssconvert_import_encoding);
+		g_free (uri);
+		inputs++;
+
+		if (gnumeric_io_error_occurred (io_context)) {
+			go_slist_free_custom (wbs, g_object_unref);
+			return NULL;
+		}
+
+		if (!wbv)
+			continue;
+
+		wbs = g_slist_prepend (wbs, wb_view_get_workbook (wbv));
+	}
+
+	return g_slist_reverse (wbs);
+}
+
+/*
+ * Look at a set of workbooks, and pick a sheet size that would
+ * be good for sheets in a workbook merging them all.
+ */
+static void
+suggest_size (GSList *wbs, int *csuggest, int *rsuggest)
+{
+	GSList *l;
+	int rmax = 0;
+	int cmax = 0;
+
+	for (l = wbs; l; l = l->next) {
+		Workbook *wb = l->data;
+
+		WORKBOOK_FOREACH_SHEET (wb, sheet, {
+			int r = gnm_sheet_get_max_rows (sheet);
+			int c = gnm_sheet_get_max_cols (sheet);
+			if (r > rmax) rmax = r;
+			if (c > cmax) cmax = c;
+		});
+	}
+
+	gnm_sheet_suggest_size (&cmax, &rmax);
+	*csuggest = cmax;
+	*rsuggest = rmax;
+}
+
+static void
+cb_fixup_name_wb (const char *name, GnmNamedExpr *nexpr, Workbook *wb)
+{
+	if (nexpr->pos.wb)
+		nexpr->pos.wb = wb;
+}
+
+
+/* Append the sheets of workbook wb2 to workbook wb.  Resize sheets
+   if necessary.  Fix workbook links in sheet if necessary.
+   Merge names in workbook scope (conflicts result in an error). */
+static gboolean
+merge_single (Workbook *wb, Workbook *wb2,
+	      int cmax, int rmax,
+	      GOCmdContext *cc)
+{
+	/* Move names with workbook scope in wb2 over to wb */
+	GSList *names = g_slist_sort (gnm_named_expr_collection_list (wb2->names),
+				      (GCompareFunc)expr_name_cmp_by_name);
+	GSList *p;
+	GnmParsePos pp;
+
+	parse_pos_init (&pp, wb, NULL, 0, 0);
+
+	for (p = names; p; p = p->next) {
+		GnmNamedExpr *nexpr = p->data;
+		const char *name = expr_name_name (nexpr);
+		GnmNamedExpr *nexpr2;
+		Sheet *sheet;
+
+		if (!nexpr->active)
+			continue;
+
+		if (nexpr->pos.wb == NULL || nexpr->pos.sheet != NULL)
+			continue;
+
+		/* Check for clash with existing name */
+
+		nexpr2 = expr_name_lookup (&pp, name);
+		if (nexpr2 != NULL) {
+			g_printerr (_("Name conflict during merge: '%s' appears twice at workbook scope.\n"),
+				    name);
+			g_slist_free (names);
+			return TRUE;
+		}
+
+		/* Move name scope to workbook wb */
+		sheet = workbook_sheet_by_index (wb2, 0);
+		expr_name_set_scope (nexpr, sheet);
+		nexpr->pos.wb = wb;
+		expr_name_set_scope (nexpr, NULL);
+	}
+	g_slist_free (names);
+
+	while (workbook_sheet_count (wb2) > 0) {
+		/* Remove sheet from incoming workbook */
+		Sheet *sheet = workbook_sheet_by_index (wb2, 0);
+		int loc = workbook_sheet_count (wb);
+		GOUndo *undo;
+		char *sheet_name;
+
+		g_object_ref (sheet);
+		workbook_sheet_delete (sheet);
+		sheet->workbook = wb;
+
+		/* Fix names that reference the old workbook */
+		gnm_sheet_foreach_name (sheet, (GHFunc)cb_fixup_name_wb, wb);
+
+		undo = gnm_sheet_resize (sheet, cmax, rmax, cc);
+		if (undo)
+			g_object_unref (undo);
+
+		/* Pick a free sheet name */
+		sheet_name = workbook_sheet_get_free_name
+			(wb, sheet->name_unquoted, FALSE, TRUE);
+		g_object_set (sheet, "name", sheet_name, NULL);
+		g_free (sheet_name);
+
+		/* Insert and revive the sheet */
+		workbook_sheet_attach_at_pos (wb, sheet, loc);
+		dependents_revive_sheet (sheet);
+		g_object_unref (sheet);
+	}
+
+	return FALSE;
+}
+
+/* Merge a collection of workbooks into one. */
+static gboolean
+merge (Workbook *wb, char const *inputs[],
+       GOFileOpener *fo, IOContext *io_context, GOCmdContext *cc)
+{
+	GSList *wbs, *l;
+	int result = 0;
+	int cmax, rmax;
+
+	wbs = read_files_to_merge (inputs, fo, io_context, cc);
+	if (gnumeric_io_error_occurred (io_context)) {
+		gnumeric_io_error_display (io_context);
+		return TRUE;
+	}
+
+	suggest_size (wbs, &cmax, &rmax);
+
+	for (l = wbs; l; l = l->next) {
+		Workbook *wb2 = l->data;
+		const char *uri = go_doc_get_uri (GO_DOC (wb2));
+
+		g_printerr ("Adding sheets from %s\n", uri);
+
+		result = merge_single (wb, wb2, cmax, rmax, cc);
+		if (result)
+			break;
+	}
+
+	go_slist_free_custom (wbs, g_object_unref);
+	return result;
+}
+
 static int
-convert (char const *inarg, char const *outarg,
+convert (char const *inarg, char const *outarg, char const *mergeargs[],
 	 GOCmdContext *cc)
 {
 	int res = 0;
@@ -288,8 +473,14 @@ convert (char const *inarg, char const *outarg,
 
 	if (fs != NULL) {
 		IOContext *io_context = gnumeric_io_context_new (cc);
-		WorkbookView *wbv = wb_view_new_from_uri (infile, fo,
-			io_context, ssconvert_import_encoding);
+		WorkbookView *wbv;
+		if (mergeargs==NULL) {
+			wbv = wb_view_new_from_uri (infile, fo,
+						    io_context,
+						    ssconvert_import_encoding);
+		} else {
+			wbv = workbook_view_new (NULL);
+		}
 
 		if (wbv == NULL || gnumeric_io_error_occurred (io_context)) {
 			gnumeric_io_error_display (io_context);
@@ -304,6 +495,11 @@ convert (char const *inarg, char const *outarg,
 				goto out;
 			}
 
+			if (mergeargs!=NULL) {
+				if (merge (wb, mergeargs, fo, io_context, cc))
+					goto out;
+			}
+
 			if (ssconvert_goal_seek) {
 				int i;
 
@@ -380,7 +576,7 @@ main (int argc, char const **argv)
 		return 0;
 	}
 
-	gnm_init (FALSE);
+	gnm_init ();
 
 	cc = cmd_context_stderr_new ();
 	gnm_plugins_init (GO_CMD_CONTEXT (cc));
@@ -399,8 +595,10 @@ main (int argc, char const **argv)
 		list_them (&go_get_file_openers,
 			   (get_desc_f) &go_file_opener_get_id,
 			   (get_desc_f) &go_file_opener_get_description);
-	else if (argc == 2 || argc == 3) {
-		res = convert (argv[1], argv[2], cc);
+	else if (ssconvert_merge_target!=NULL && argc>=3) {
+		res = convert (argv[1], ssconvert_merge_target, argv+1, cc);
+	} else if (argc == 2 || argc == 3) {
+		res = convert (argv[1], argv[2], NULL, cc);
 	} else {
 		g_printerr (_("Usage: %s [OPTION...] %s\n"),
 			    g_get_prgname (),
