@@ -26,16 +26,13 @@
 #include "gnumeric.h"
 #include "stf.h"
 
-#include <goffice/app/file.h>
+#include <goffice/goffice.h>
 #include "cell.h"
 #include "sheet.h"
 #include "sheet-view.h"
 #include "sheet-style.h"
 #include "style.h"
 #include "mstyle.h"
-#include <goffice/app/io-context-priv.h>
-#include <goffice/utils/go-glib-extras.h>
-#include <goffice/app/go-doc.h>
 #include "command-context.h"
 #include "wbc-gtk.h"
 #include "workbook-view.h"
@@ -522,7 +519,7 @@ csv_tsv_probe (GOFileOpener const *fo, GsfInput *input, FileProbeLevel pl)
 			/* Also, ignore a byte-order mark which may be used to
 			 * indicate UTF-8; see
 			 * http://en.wikipedia.org/wiki/Byte_Order_Mark for
-			 * background. 
+			 * background.
 			 */
 			if (p == header_utf8 && uc == 0x0000FEFF) {
 				continue;
