@@ -36,15 +36,8 @@
 #include "numbers.h"
 #include "sheet-object-graph.h"
 #include "graph.h"
-#include <goffice/graph/gog-graph.h>
-#include <goffice/graph/gog-object.h>
-#include <goffice/graph/gog-chart.h>
-#include <goffice/graph/gog-plot.h>
-#include <goffice/graph/gog-series.h>
-#include <goffice/graph/gog-style.h>
-#include <goffice/graph/gog-styled-object.h>
-#include <goffice/utils/go-glib-extras.h>
-#include <goffice/utils/go-marker.h>
+#include <goffice/goffice.h>
+#include "sheet.h"
 
 static gboolean
 analysis_tool_kaplan_meier_engine_run (data_analysis_output_t *dao,
@@ -84,21 +77,21 @@ analysis_tool_kaplan_meier_engine_run (data_analysis_output_t *dao,
 
 	GSList *gl = info->group_list;
 
-	fd_small = gnm_func_lookup ("SMALL", NULL);
+	fd_small = gnm_func_lookup_or_add_placeholder ("SMALL", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
 	gnm_func_ref (fd_small);
-	fd_if = gnm_func_lookup ("IF", NULL);
+	fd_if = gnm_func_lookup_or_add_placeholder ("IF", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
 	gnm_func_ref (fd_if);
-	fd_iserror = gnm_func_lookup ("ISERROR", NULL);
+	fd_iserror = gnm_func_lookup_or_add_placeholder ("ISERROR", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
 	gnm_func_ref (fd_iserror);
-	fd_sum = gnm_func_lookup ("SUM", NULL);
+	fd_sum = gnm_func_lookup_or_add_placeholder ("SUM", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
 	gnm_func_ref (fd_sum);
 	
 	if (info->std_err) {
-		fd_sqrt = gnm_func_lookup ("SQRT", NULL);
+		fd_sqrt = gnm_func_lookup_or_add_placeholder ("SQRT", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
 		gnm_func_ref (fd_sqrt);
 	}
 	if (info->median) {
-		fd_min = gnm_func_lookup ("MIN", NULL);
+		fd_min = gnm_func_lookup_or_add_placeholder ("MIN", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
 		gnm_func_ref (fd_min);
 	}
 
@@ -112,7 +105,7 @@ analysis_tool_kaplan_meier_engine_run (data_analysis_output_t *dao,
 	if (info->chart) {
 		GogChart     *chart;
 		
-		graph = g_object_new (GOG_GRAPH_TYPE, NULL);
+		graph = g_object_new (GOG_TYPE_GRAPH, NULL);
 		chart = GOG_CHART (gog_object_add_by_name (
 						   GOG_OBJECT (graph), "Chart", NULL));
 
@@ -380,16 +373,16 @@ analysis_tool_kaplan_meier_engine_run (data_analysis_output_t *dao,
 		
 		dao_set_format  (dao, prob_col, 2, prob_col, rows + 1, "0.00%");
 		
-		dao_set_cell_array_expr (dao, 0, 2, gnm_expr_copy (expr_at_risk)); 	
-		dao_set_cell_array_expr (dao, 1, 2, gnm_expr_copy (expr_deaths)); 	
+		dao_set_cell_array_expr (dao, 0, 2, gnm_expr_copy (expr_at_risk));
+		dao_set_cell_array_expr (dao, 1, 2, gnm_expr_copy (expr_deaths));
 		dao_set_cell_expr (dao, prob_col, 2, expr_prob_zero);
 		
 		if (expr_censures != NULL)
 			dao_set_cell_array_expr (dao, 2, 2, gnm_expr_copy (expr_censures));
 		
 		for (row = 1; row < rows; row++) {
-			dao_set_cell_array_expr (dao, 0, 2+row, gnm_expr_copy (expr_at_risk)); 	
-			dao_set_cell_array_expr (dao, 1, 2+row, gnm_expr_copy (expr_deaths)); 	
+			dao_set_cell_array_expr (dao, 0, 2+row, gnm_expr_copy (expr_at_risk));
+			dao_set_cell_array_expr (dao, 1, 2+row, gnm_expr_copy (expr_deaths));
 			if (expr_censures != NULL)
 				dao_set_cell_array_expr (dao, 2, 2+row, gnm_expr_copy (expr_censures));
 			dao_set_cell_array_expr (dao, prob_col, 2+row, gnm_expr_copy (expr_prob)); 
@@ -413,7 +406,7 @@ analysis_tool_kaplan_meier_engine_run (data_analysis_output_t *dao,
 		if (info->chart) {
 			GogSeries    *series;
 			GOData *probabilities;
-			GogStyle  *style;
+			GOStyle  *style;
 			
 			probabilities = dao_go_data_vector (dao, prob_col, 2, prob_col, 1+rows);
 			
@@ -422,10 +415,10 @@ analysis_tool_kaplan_meier_engine_run (data_analysis_output_t *dao,
 			gog_series_set_dim (series, 0, times, NULL);
 			gog_series_set_dim (series, 1, probabilities, NULL);
 			
-			style = gog_styled_object_get_style (GOG_STYLED_OBJECT (series));
+			style = go_styled_object_get_style (GO_STYLED_OBJECT (series));
 			style->marker.auto_shape = FALSE;
 			go_marker_set_shape (style->marker.mark, GO_MARKER_NONE);
-			gog_styled_object_set_style (GOG_STYLED_OBJECT (series), style);
+			go_styled_object_set_style (GO_STYLED_OBJECT (series), style);
 			
 			if (info->censored && info->ticks) {
 				GOData *censures;
@@ -445,13 +438,13 @@ analysis_tool_kaplan_meier_engine_run (data_analysis_output_t *dao,
 				gog_series_set_dim (series, 0, times, NULL);
 				gog_series_set_dim (series, 1, censures, NULL);
 				
-				style = gog_styled_object_get_style (GOG_STYLED_OBJECT (series));
+				style = go_styled_object_get_style (GO_STYLED_OBJECT (series));
 				style->marker.auto_shape = FALSE;
 				go_marker_set_shape (style->marker.mark, GO_MARKER_TRIANGLE_DOWN);
 				style->line.dash_type = GO_LINE_NONE;
 				style->line.auto_dash = FALSE;
 				style->line.width = 0;
-				gog_styled_object_set_style (GOG_STYLED_OBJECT (series), style);
+				go_styled_object_set_style (GO_STYLED_OBJECT (series), style);
 			}
 		}
 
@@ -531,7 +524,7 @@ analysis_tool_kaplan_meier_engine_run (data_analysis_output_t *dao,
 		GnmExpr const *expr_n_total = gnm_expr_new_constant (value_new_int (0));
 		GnmExpr const *expr_death_total = gnm_expr_new_constant (value_new_int (0));
 
-		fd_chidist = gnm_func_lookup ("CHIDIST", NULL);
+		fd_chidist = gnm_func_lookup_or_add_placeholder ("CHIDIST", dao->sheet ? dao->sheet->workbook : NULL, FALSE);
 		gnm_func_ref (fd_chidist);
 
 		dao_set_italic (dao, 1, logrank_test_y_offset, 1, logrank_test_y_offset+3);
