@@ -46,8 +46,7 @@
 #include "value.h"
 #include "widgets/gnumeric-expr-entry.h"
 
-#include <goffice/utils/go-font.h>
-#include <goffice/utils/go-pango-extras.h>
+#include <goffice/goffice.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n-lib.h>
 #include <string.h>
@@ -1014,7 +1013,7 @@ wbcg_insert_object (WBCGtk *wbcg, SheetObject *so)
 /**
  * wbcg_insert_object_clear :
  * @wbcg : #WBCGtk
- * 
+ *
  * If we are preparing to insert a new object, unref the object, and restore
  * a normal state to the scgs that was changed in wbcg_insert_object
  * (e.g.  visiblity of cursors)
@@ -1169,7 +1168,7 @@ wbc_gtk_attach_guru_with_unfocused_rs (WBCGtk *wbcg, GtkWidget *guru,
 
 	wbcg_edit_attach_guru_main (wbcg, guru);
 
-	if (gnm_app_prefs->unfocused_range_selection) {
+	if (gnm_conf_get_dialogs_rs_unfocused ()) {
 		if (gee)
 			wbcg_set_entry (wbcg, gee);
 	} else
