@@ -8,9 +8,9 @@ typedef struct _GnmCComboFooView GnmCComboFooView;
 typedef struct {
 	GTypeInterface base;
 
-	void		(*activate)	(SheetObject *so, GtkWidget *popup,   GtkTreeView *list,
+	gboolean	(*activate)	(SheetObject *so, GtkWidget *popup,   GtkTreeView *list,
 					 WBCGtk *wbcg);
-	GtkListStore *	(*fill_model)   (SheetObject *so, GtkTreePath **clip, GtkTreePath **select);
+	GtkWidget *	(*create_list)  (SheetObject *so, GtkTreePath **clip, GtkTreePath **select);
 	GtkWidget *	(*create_arrow) (SheetObject *so);
 } GnmCComboFooViewIface;
 
