@@ -10,6 +10,7 @@
  * (C) 1998, 1999, 2000 Miguel de Icaza
  * (C) 2000-2001 Ximian, Inc.
  * (C) 2002-2007 Jody Goldberg
+ * Copyright (C) 1999-2009 Morten Welinder (terra@gnome.org)
  */
 #include <gnumeric-config.h>
 #include "gnumeric.h"
@@ -19,6 +20,7 @@
 #include "workbook-control.h"
 #include "command-context.h"
 #include "application.h"
+#include "gnumeric-gconf.h"
 #include "sheet.h"
 #include "sheet-view.h"
 #include "sheet-control.h"
@@ -34,19 +36,9 @@
 #include "gutils.h"
 #include "gnm-marshalers.h"
 #include "style-color.h"
+#include "sheet-style.h"
 
-#include <goffice/app/file.h>
-#include <goffice/app/io-context.h>
-#include <goffice/utils/go-file.h>
-#include <goffice/utils/go-glib-extras.h>
-
-#ifdef GNM_WITH_GTK
-#ifdef GNM_WITH_GNOME
-#include <bonobo/bonobo-main.h>
-#else
-#include <gtk/gtkmain.h> /* for gtk_main_quit */
-#endif
-#endif /* GNM_WITH_GTK */
+#include <goffice/goffice.h>
 
 #include <gsf/gsf-doc-meta-data.h>
 #include <gsf/gsf-impl-utils.h>
@@ -56,7 +48,7 @@
 
 enum {
 	PROP_0,
-	RECALC_MODE,
+	RECALC_MODE
 };
 enum {
 	SHEET_ORDER_CHANGED,
@@ -70,7 +62,7 @@ static GObjectClass *workbook_parent_class;
 static void
 cb_saver_finalize (Workbook *wb, GOFileSaver *saver)
 {
-	g_return_if_fail (IS_GO_FILE_SAVER (saver));
+	g_return_if_fail (GO_IS_FILE_SAVER (saver));
 	g_return_if_fail (IS_WORKBOOK (wb));
 	g_return_if_fail (wb->file_saver == saver);
 	wb->file_saver = NULL;
@@ -93,7 +85,7 @@ static void
 workbook_dispose (GObject *wb_object)
 {
 	Workbook *wb = WORKBOOK (wb_object);
-	GList *sheets, *ptr;
+	GSList *sheets, *ptr;
 
 	wb->during_destruction = TRUE;
 
@@ -126,7 +118,7 @@ workbook_dispose (GObject *wb_object)
 		Sheet *sheet = ptr->data;
 		workbook_sheet_delete (sheet);
 	}
-	g_list_free (sheets);
+	g_slist_free (sheets);
 
 	/* TODO : This should be earlier when we figure out how to deal with
 	 * the issue raised by 'pristine'.
@@ -160,15 +152,6 @@ workbook_finalize (GObject *obj)
 	g_ptr_array_free (wb->sheets, TRUE);
 	wb->sheets = NULL;
 
-	/* this has no business being here */
-#ifdef GNM_WITH_GTK
-	if (initial_workbook_open_complete && gnm_app_workbook_list () == NULL)
-#ifdef GNM_WITH_GNOME
-		bonobo_main_quit ();
-#else
-		gtk_main_quit ();
-#endif
-#endif
 	workbook_parent_class->finalize (obj);
 }
 
@@ -194,7 +177,7 @@ workbook_init (GObject *object)
 	wb->iteration.tolerance = .001;
 	wb->recalc_auto = TRUE;
 
-	wb->date_conv.use_1904 = FALSE;
+	workbook_set_1904 (wb, FALSE);
 
 	wb->file_format_level = FILE_FL_NEW;
 	wb->file_saver        = NULL;
@@ -375,8 +358,12 @@ Workbook *
 workbook_new_with_sheets (int sheet_count)
 {
 	Workbook *wb = workbook_new ();
+	int cols = gnm_conf_get_core_workbook_n_cols ();
+	int rows = gnm_conf_get_core_workbook_n_rows ();
+	if (!gnm_sheet_valid_size (cols, rows))
+		gnm_sheet_suggest_size (&cols, &rows);
 	while (sheet_count-- > 0)
-		workbook_sheet_add (wb, -1);
+		workbook_sheet_add (wb, -1, cols, rows);
 	go_doc_set_dirty (GO_DOC (wb), FALSE);
 	GO_DOC (wb)->pristine = TRUE;
 	return wb;
@@ -545,12 +532,37 @@ workbook_share_expressions (Workbook *wb, gboolean freeit)
 	return es;
 }
 
+void
+workbook_optimize_style (Workbook *wb)
+{
+	WORKBOOK_FOREACH_SHEET (wb, sheet, {
+		sheet_style_optimize (sheet);
+	});
+}
+
 GSList *
 workbook_local_functions (Workbook const *wb)
 {
 	return NULL;
 }
 
+void
+workbook_foreach_name (Workbook const *wb, gboolean globals_only,
+		       GHFunc func, gpointer data)
+{
+	g_return_if_fail (IS_WORKBOOK (wb));
+
+	if (wb->names)
+		gnm_named_expr_collection_foreach (wb->names, func, data);
+
+	if (!globals_only) {
+		WORKBOOK_FOREACH_SHEET (wb, sheet, {
+				gnm_sheet_foreach_name (sheet, func, data);
+		});
+	}
+}
+
+
 gboolean
 workbook_enable_recursive_dirty (Workbook *wb, gboolean enable)
 {
@@ -640,17 +652,17 @@ workbook_detach_view (WorkbookView *wbv)
  * workbook_sheets : Get an ordered list of the sheets in the workbook
  *                   The caller is required to free the list.
  */
-GList *
+GSList *
 workbook_sheets (Workbook const *wb)
 {
-	GList *list = NULL;
+	GSList *list = NULL;
 
 	g_return_val_if_fail (IS_WORKBOOK (wb), NULL);
 
 	if (wb->sheets) {
 		int i = wb->sheets->len;
 		while (i-- > 0)
-			list = g_list_prepend (list,
+			list = g_slist_prepend (list,
 				g_ptr_array_index (wb->sheets, i));
 	}
 
@@ -869,10 +881,10 @@ workbook_sheet_attach (Workbook *wb, Sheet *new_sheet)
  * returned is not ref'd.  (The ref belongs to the workbook.)
  */
 Sheet *
-workbook_sheet_add (Workbook *wb, int pos)
+workbook_sheet_add (Workbook *wb, int pos, int columns, int rows)
 {
 	char *name = workbook_sheet_get_free_name (wb, _("Sheet"), TRUE, FALSE);
-	Sheet *new_sheet = sheet_new (wb, name);
+	Sheet *new_sheet = sheet_new (wb, name, columns, rows);
 	g_free (name);
 
 	if (pos == -1)
@@ -1130,42 +1142,57 @@ workbook_sheet_reorder (Workbook *wb, GSList *new_order)
 }
 
 /**
- * workbook_uses_1904 :
- * @wb :
+ * workbook_date_conv :
+ * @wb : Workbook
  *
- * Does @wb use the 1904 date convention ?  This could be expanded to return a
- * locale-ish type object to get passed around.  However, since we use libc for
- * some of the formatting and parsing we can not get around setting the actual
- * locale globally and there is not much that I can think of to put in here for
- * now.  Hence I'll leave it as a boolean.
+ * Returns: the date convention in effect for the workbook.
  **/
 GODateConventions const *
 workbook_date_conv (Workbook const *wb)
 {
 	g_return_val_if_fail (wb != NULL, NULL);
-	return &wb->date_conv;
+	return wb->date_conv;
 }
 
 /**
- * workbook_set_1904 :
- * @wb :
- * @flag : new value
+ * workbook_set_date_conv :
+ * @wb : worknook
+ * @date_conv : new date convention
  *
- * Sets the 1904 flag to @flag and returns the old value.
+ * Sets the date convention @date_conv.
  * NOTE : THIS IS NOT A SMART ROUTINE.  If you want to actually change this
  * We'll need to recalc and rerender everything.  That will need to be done
  * externally.
  **/
-gboolean
-workbook_set_1904 (Workbook *wb, gboolean flag)
+void
+workbook_set_date_conv (Workbook *wb, GODateConventions const *date_conv)
 {
-	gboolean old_val;
+	g_return_if_fail (IS_WORKBOOK (wb));
+	g_return_if_fail (date_conv != NULL);
 
-	g_return_val_if_fail (IS_WORKBOOK (wb), FALSE);
+	wb->date_conv = date_conv;
+}
 
-	old_val = wb->date_conv.use_1904;
-	wb->date_conv.use_1904 = flag;
-	return old_val;
+void
+workbook_set_1904 (Workbook *wb, gboolean base1904)
+{
+	GODateConventions const *date_conv =
+		go_date_conv_from_str (base1904 ? "Apple:1904" : "Lotus:1900");
+	workbook_set_date_conv (wb, date_conv);
+}
+
+GnmSheetSize const *
+workbook_get_sheet_size (Workbook const *wb)
+{
+	if (wb == NULL || workbook_sheet_count (wb) == 0) {
+		static const GnmSheetSize max_size = {
+			GNM_MAX_COLS, GNM_MAX_ROWS
+		};
+
+		return &max_size;
+	}
+
+	return gnm_sheet_get_size (workbook_sheet_by_index (wb, 0));
 }
 
 /* ------------------------------------------------------------------------- */
@@ -1380,4 +1407,4 @@ workbook_sheet_state_diff (const WorkbookSheetState *wss_a, const WorkbookSheetS
 
 GSF_CLASS (Workbook, workbook,
 	   workbook_class_init, workbook_init,
-	   GO_DOC_TYPE);
+	   GO_TYPE_DOC)
