@@ -40,7 +40,6 @@
 #include <expr-impl.h>
 #include <expr-name.h>
 #include <value.h>
-#include <str.h>
 #include <ranges.h>
 #include <mstyle.h>
 #include <style-border.h>
@@ -57,8 +56,7 @@
 #include <tools/scenarios.h>
 #include <gnumeric-gconf.h>
 
-#include <goffice/app/go-doc.h>
-#include <goffice/app/file.h>
+#include <goffice/goffice.h>
 #include <gsf/gsf-libxml.h>
 #include <gsf/gsf-output-gzip.h>
 #include <gsf/gsf-doc-meta-data.h>
@@ -273,6 +271,8 @@ xml_write_breaks (GnmOutputXML *state, GnmPageBreaks *breaks)
 			gsf_xml_out_add_cstr_unchecked  (state->output, "type", "manual");
 		else if (binfo->type == GNM_PAGE_BREAK_DATA_SLICE)
 			gsf_xml_out_add_cstr_unchecked  (state->output, "type", "data-slice");
+		else if (binfo->type == GNM_PAGE_BREAK_AUTO)
+			gsf_xml_out_add_cstr_unchecked  (state->output, "type", "auto");
 		gsf_xml_out_end_element (state->output); /* </break> */
 	}
 	gsf_xml_out_end_element (state->output);
@@ -617,7 +617,7 @@ static void
 xml_write_styles (GnmOutputXML *state)
 {
 	GnmStyleList *styles =
-		g_slist_sort (sheet_style_get_list (state->sheet, NULL),
+		g_slist_sort (sheet_style_get_range (state->sheet, NULL),
 			      (GCompareFunc)cb_sheet_style_order);
 	if (styles != NULL) {
 		GnmStyleList *ptr;
@@ -1282,7 +1282,7 @@ gnm_xml_file_save (GOFileSaver const *fs, IOContext *io_context,
 	if (NULL != extension && g_ascii_strcasecmp (extension, "xml") == 0)
 		compress = FALSE;
 	else
-		compress = (gnm_app_prefs->xml_compression_level > 0);
+		compress = (gnm_conf_get_core_xml_compression_level () > 0);
 
 	if (compress) {
 		gzout  = gsf_output_gzip_new (output, NULL);
